### Artificial Regeneration Survival, Competitiveness, Height, and GLD ###

library(multcomp)
library(car)
library(lme4)
library(piecewiseSEM) 
library(blmeco) 
library(dfoptim) 
library(optimx)
library(nloptr)
library(plyr)

setwd("~/Library/Mobile Documents/com~apple~CloudDocs/Purdue PC/TNC Oak Project/TNC Forests Submission/Supplementary Materials/Data")

AR18<-read.csv("Artificial Regen 2018.csv")
    AR18$Height.Ft<-NULL #dropped column with superflous original data (height measured in feet)
    AR18$Notes<-NULL  #drop notes column
    AR18$Date<-NULL  #drop date column
    AR18$X<-NULL #other notes
    
    head(AR18)
    summary(AR18) #check site totals: Knapp 450, McKinney 793, NS 800, Wulfman 800

   
tot.surv1<-aggregate(AR18$Alive, by=list(AR18$Fertilized,AR18$Silvi,AR18$Site,AR18$Fence), FUN = sum)
  names(tot.surv1)<-c("Fert","Silvi","Site","Fence","Survived")
  tot.surv.fert<-cbind.data.frame(tot.surv1["Site"], tot.surv1["Silvi"], tot.surv1["Fence"],tot.surv1["Fert"],tot.surv1["Survived"])
  tot.surv.fert$Planted<-c(50,50,50,50,50,50, 50,50,49,50,50,50,50,50, 50,50,50,50,50,50,50,50, 50,50,50,50,50,50,50,50,
                           50,50,50,50, 50,50,51,50,50,50,46,46, 50,50,50,50,50,50,50,50, 50,50,50,50,50,50,50,50)
        
  # numbers other than 50 reflect errors in original fence placement relative to planted seedlings
  
  tot.surv.fert$Prop.surv<-tot.surv.fert$Survived/tot.surv.fert$Planted
 
  aggregate(tot.surv.fert$Prop.surv, by=list(tot.surv.fert$Silvi,tot.surv.fert$Fence,tot.surv.fert$Fert), FUN=mean)
      aggregate(tot.surv.fert$Prop.surv, by=list(tot.surv.fert$Silvi,tot.surv.fert$Fence), FUN=mean)
  
  summary(tot.surv.fert)
  

### Mixed Models for Survival###
# must run AllFit code at bottom of file before running mixed models containing certain optimizer functions (e.g. nlminbw)
  
  glmer.surv.full<-glmer(Alive ~ (Fertilized + Fence + Silvi)^2 +(1|Site)+(1|Fertilized:Site)+(1|Fence:Site)+(1|Silvi:Site), data = AR18[which(is.na(AR18$Fertilized)==F),], family=binomial, glmerControl(optimizer = "nlminbw", optCtrl=list(maxfun=1000000)))
    ranef(glmer.surv.full)

  glmer.surv.full_rint<-glmer(Alive ~ (Fertilized + Fence + Silvi)^2 +(1|Site), data = AR18[which(is.na(AR18$Fertilized)==F),], family=binomial, glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1000000)))
  
    anova(glmer.surv.full,glmer.surv.full_rint) #keep random effects   
  
  glmer.surv.INT1<-glmer(Alive ~ Fertilized + Fence * Silvi +Fertilized:Silvi +(1|Site)+(1|Fertilized:Site)+(1|Fence:Site)+(1|Silvi:Site), data = AR18[which(is.na(AR18$Fertilized)==F),], family=binomial, glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1000000)))
    anova(glmer.surv.full,glmer.surv.INT1) #fert x fence p = 0.27
  glmer.surv.INT2<-glmer(Alive ~ Fertilized * Fence + Silvi +Fertilized:Silvi +(1|Site)+(1|Fertilized:Site)+(1|Fence:Site)+(1|Silvi:Site), data = AR18[which(is.na(AR18$Fertilized)==F),], family=binomial, glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1000000)))
    anova(glmer.surv.full,glmer.surv.INT2) #fence x silvi p < 0.001
  glmer.surv.INT3<-glmer(Alive ~ Fertilized * Fence + Fence * Silvi +(1|Site)+(1|Fertilized:Site)+(1|Fence:Site)+(1|Silvi:Site), data = AR18[which(is.na(AR18$Fertilized)==F),], family=binomial, glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1000000)))
    anova(glmer.surv.full, glmer.surv.INT3) #fert x silvi p = 0.71
  
  #fence x silvi interaction is significant when dropped from full model
  #compare to additive model

  glmer.surv.add<-glmer(Alive ~ Fertilized + Fence + Silvi +(1|Site)+(1|Fertilized:Site)+(1|Fence:Site)+(1|Silvi:Site), data = AR18[which(is.na(AR18$Fertilized)==F),], family=binomial, glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1000000)))
  glmer.surv.sxf <-glmer(Alive ~ Fertilized + Fence * Silvi +(1|Site)+(1|Fertilized:Site)+(1|Fence:Site)+(1|Silvi:Site), data = AR18[which(is.na(AR18$Fertilized)==F),], family=binomial, glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1000000)))
    anova(glmer.surv.sxf,glmer.surv.add) #fence x silvi p < 0.001
    
  best.mod<-glmer.surv.sxf
    
  Anova(best.mod) 
    summary(best.mod) 
    rsquared(best.mod) 
    ranef(best.mod)
    dispersion_glmer(best.mod) #very near 1 (0.981), not overdispersed
  
  summary(glht(best.mod))   #deviance = 948.1, residual df = 852
  1 - pchisq(948.1, 852)  #p = 0.012,  model DOES NOT fit well
  qchisq(p=.95,df=852) #critical model deviance threshold = 921.0
  
  cbind(exp(summary(best.mod)$coefficients[,"Estimate"]),
        exp(summary(best.mod)$coefficients[,"Std. Error"]),
        summary(best.mod)$coefficients[,"z value"],
        exp(confint(glht(best.mod, parm="beta_",method="Wald"))$confint[,2:3]))
  
  confint(glht(best.mod, parm="beta_",method="Wald"))$confint
  
  cont.mat <- rbind("Fert effect"  =              c(0,1, 0, 0, 0, 0,0, 0, 0),
                    "Fence effect: control v 0" = c(0,0, 1, 0, 0, 0,0, 0, 0),
                    "Fence: MR v control" =       c(0,0, 0, 0, 0, 0,1, 0, 0),
                    "Fence: TH v control" =       c(0,0, 0, 0, 0, 0,0, 1, 0),
                    "Fence: SW v control" =       c(0,0, 0, 0, 0, 0,0, 0, 1),
                    "Fence: MR v TH"      =       c(0,0, 0, 0, 0, 0,1,-1, 0),
                    "Fence: MR v SW"      =       c(0,0, 0, 0, 0, 0,1, 0,-1),
                    "Fence: TH v SW"      =       c(0,0, 0, 0, 0, 0,0, 1,-1),
                    "MR v Control (NF)"   =       c(0,0, 0, 1, 0, 0,0, 0, 0),
                    "TH v Control (NF)"   =       c(0,0, 0, 0, 1, 0,0, 0, 0),
                    "SW v Control (NF)"   =       c(0,0, 0, 0, 0, 1,0, 0, 0),
                    "MR v TH (NF)"        =       c(0,0, 0, 1,-1, 0,0, 0, 0),
                    "MR v SW (NF)"        =       c(0,0, 0, 1, 0,-1,0, 0, 0),
                    "TH v SW (NF)"        =       c(0,0, 0, 0, 1,-1,0, 0, 0))
  summary(glht(best.mod, linfct=cont.mat))

 # Computing predicted survival probabilities
 ## based on R documentation for predict.merMod
 newdata <- with(AR18, expand.grid(Fertilized=unique(Fertilized[which(is.na(Fertilized)==F)]),Silvi=unique(Silvi), Fence=unique(Fence),Site=unique(Site)))
 newdata$pred<- predict(best.mod,newdata,re.form=NA, type="response") #predicted probabilities of survival for each treatment combination
 newdata.nosite<-newdata[1:16,c(1:3,5)]#predicted probabilities of competitiveness for each treatment combination
 
 pred.ordered<-newdata.nosite[order(newdata.nosite$Fence, newdata.nosite$Silvi,newdata.nosite$Fertilized),]
  cbind(pred.ordered[,1:3],round(pred.ordered[,4],3))


#### Competitiveness ####
  
  AR18<-read.csv("Artificial Regen 2018.csv")
  AR18$Height.Ft<-NULL #dropped column with superflous original data (height measured in feet)
  AR18$Notes<-NULL  #drop notes column
  AR18$Date<-NULL  #drop date column
  AR18$X<-NULL #other notes
  
  head(AR18)
  summary(AR18) #check site totals: Knapp 450, McKinney 793, NS 800, Wulfman 800
  
  AR18.alive<-AR18[which(AR18$Alive==1),]
  
  
  plot(as.factor(AR18.alive$Comp)) #uniformly distributed
  plot(AR18.alive$Crown.Class) #heavy on suppressed and intermediate seedlings
  
  plot(AR18.alive$Comp)
  
  AR18.alive$Competitive<-NA
  for(i in 1:nrow(AR18.alive)){
    if(AR18.alive$Crown.Class[i]=="D"){
      AR18.alive$Competitive[i]=1}else{
        if(AR18.alive$Crown.Class[i]=="C"){
          AR18.alive$Competitive[i]=1}else{
            if(AR18.alive$Crown.Class[i]!="S"&AR18.alive$Comp[i]==0&AR18.alive$Height.cm[i]>100){
              AR18.alive$Competitive[i]=1}else{
                AR18.alive$Competitive[i]=0}}}}
  
  # if oak was ranked dominant or codominant, or if it was intermediate with no adjacent competition (i.e.,"free-to-grow") and it was > 1m (there were 43 of 866 survivors in this latter category),
  # it was deemed "competitive"
  
  sum(AR18.alive$Competitive)
  aggregate(AR18.alive$Competitive~AR18.alive$Silvi*AR18.alive$Fence*AR18.alive$Fertilized, FUN=sum)
  
  tot.comp1<-aggregate(AR18.alive$Competitive, by=list(AR18.alive$Fertilized,AR18.alive$Silvi,AR18.alive$Site,AR18.alive$Fence), FUN = sum)
  names(tot.comp1)<-c("Fert","Silvi","Site","Fence","Competitive")
  tot.comp.fert.<-cbind.data.frame(tot.comp1["Site"], tot.comp1["Silvi"], tot.comp1["Fence"],tot.comp1["Fert"],tot.comp1["Competitive"])
  nullrows<-rbind.data.frame(c("Knapp","Control",0,0,0),
                             c("Knapp","Control",0,1,0),
                             c("McKinney","Control",0,1,0),
                             c("Nelson-Stokes","Control",0,0,0),
                             c("Nelson-Stokes","Control",0,1,0),
                             c("Wulfman","Control",0,1,0))
  colnames(nullrows)<-names(tot.comp.fert.)
  str(nullrows)
  nullrows$Competitive<-as.numeric(nullrows$Competitive)
  str(tot.comp.fert.)
  tot.comp.fert.$Fence<-as.factor(tot.comp.fert.$Fence)
  tot.comp.fert<-rbind.data.frame(nullrows[1:2,],tot.comp.fert.[1:5,],nullrows[3,],tot.comp.fert.[6:11,],
                                  nullrows[4:5,],tot.comp.fert.[12:18,],nullrows[6,],tot.comp.fert.[19:52,])
  
  tot.comp.fert$Planted<-c(50,50,50,50,50,50, 50,50,49,50,50,50,50,50, 50,50,50,50,50,50,50,50, 50,50,50,50,50,50,50,50,
                           50,50,50,50, 50,50,51,50,50,50,46,46, 50,50,50,50,50,50,50,50, 50,50,50,50,50,50,50,50)
  
  tot.comp.fert$Prop.comp<-tot.comp.fert$Competitive/tot.comp.fert$Planted
  
  aggregate(tot.comp.fert$Prop.comp, by=list(tot.comp.fert$Silvi,tot.comp.fert$Fence,tot.comp.fert$Fert), FUN=mean)
  summary(tot.comp.fert)
  

### Mixed models for competitiveness ###
  
  #Create binary vector of "compeititve"
  AR18$Competitive<-NA
  for(i in 1:nrow(AR18)){
    if(AR18$Alive[i]==0){
      AR18$Competitive[i]=0}else{
        if(AR18$Crown.Class[i]=="D"){
          AR18$Competitive[i]=1}else{
            if(AR18$Crown.Class[i]=="C"){
              AR18$Competitive[i]=1}else{
                if(AR18$Crown.Class[i]!="S"&AR18$Comp[i]==0&AR18$Height.cm[i]>100){
                  AR18$Competitive[i]=1}else{
                    AR18$Competitive[i]=0}}}}}
  
  aggregate(AR18$Competitive~AR18$Silvi*AR18$Fence*AR18$Fertilized, FUN=mean)
  
  #"SC" = survivor competitiveness
  glmer.comp.SC.full<-glmer(Competitive ~ (Fertilized + Fence + Silvi)^2 +(1|Site)+(1|Fertilized:Site)+(1|Fence:Site)+(1|Silvi:Site), data = AR18[which(is.na(AR18$Fertilized)==F),], family=binomial, glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1000000)))
  glmer.comp.SC.full_rint<-glmer(Competitive ~ (Fertilized + Fence + Silvi)^2 +(1|Site), data = AR18[which(is.na(AR18$Fertilized)==F),], family=binomial, glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1000000)))
  ranef(glmer.comp.SC.full)
  
  anova(glmer.comp.SC.full,glmer.comp.SC.full_rint)   #random "slopes" significantly reduce deviance 
  
  glmer.comp.SC.INT1<-glmer(Competitive ~ Fertilized + Fence * Silvi +Fertilized:Silvi +(1|Site)+(1|Fertilized:Site)+(1|Fence:Site)+(1|Silvi:Site), data = AR18[which(is.na(AR18$Fertilized)==F),], family=binomial, glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1000000)))
  anova(glmer.comp.SC.full,glmer.comp.SC.INT1) #fert x fence p = 0.03
  glmer.comp.SC.INT2<-glmer(Competitive ~ Fertilized * Fence + Silvi +Fertilized:Silvi +(1|Site)+(1|Fertilized:Site)+(1|Fence:Site)+(1|Silvi:Site), data = AR18[which(is.na(AR18$Fertilized)==F),], family=binomial, glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1000000)))
  anova(glmer.comp.SC.full,glmer.comp.SC.INT2) #fence x silvi p = 0.002
  glmer.comp.SC.INT3<-glmer(Competitive ~ Fertilized * Fence + Fence * Silvi +(1|Site)+(1|Fertilized:Site)+(1|Fence:Site)+(1|Silvi:Site), data = AR18[which(is.na(AR18$Fertilized)==F),], family=binomial, glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1000000)))
  anova(glmer.comp.SC.full, glmer.comp.SC.INT3) #fert x silvi p = 0.14
  
  # Fert x fence and fence x silvi interactions are both significant. Do both hold up when compared to models with single interactions?
  glmer.comp.SC.cand1<-glmer(Competitive ~ Fertilized * Fence + Silvi +(1|Site)+(1|Fertilized:Site)+(1|Fence:Site)+(1|Silvi:Site), data = AR18[which(is.na(AR18$Fertilized)==F),], family=binomial, glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1000000)))
  anova(glmer.comp.SC.INT3,glmer.comp.SC.cand1) #fence x silvi p = 0.002
  glmer.comp.SC.cand2<-glmer(Competitive ~ Fertilized + Fence * Silvi +(1|Site)+(1|Fertilized:Site)+(1|Fence:Site)+(1|Silvi:Site), data = AR18[which(is.na(AR18$Fertilized)==F),], family=binomial, glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1000000)))
  anova(glmer.comp.SC.INT3,glmer.comp.SC.cand2) #fence x fert p = 0.03
  
  glmer.comp.SC.best<-glmer.comp.SC.INT3
  Anova(glmer.comp.SC.best) #all terms included are significant
  summary(glht(glmer.comp.SC.best))
  exp(summary(glmer.comp.SC.best)$coefficients[,1:2])
  #messy due to so few in control....
  
  #####################################
  ## Fit Model without control plots ##
  ## and check that same model selection still holds ##
  AR18.TRT<-AR18[which(AR18$Silvi!="Control"),]
  
  mod.full2<-glmer(Competitive ~ (Fertilized + Fence + Silvi)^2 +(1|Site)+(1|Fertilized:Site)+(1|Fence:Site)+(1|Silvi:Site), data = AR18.TRT[which(is.na(AR18.TRT$Fertilized)==F),], family=binomial, glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1000000)))
  mod.full2_rint<-glmer(Competitive ~ (Fertilized + Fence + Silvi)^2 +(1|Site), data = AR18.TRT[which(is.na(AR18.TRT$Fertilized)==F),], family=binomial, glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1000000)))
  ranef(mod.full2)
  
  anova(mod.full2,mod.full2_rint)   #random "slopes" still significantly reduce deviance 
  
  mod.INT1<-glmer(Competitive ~ Fertilized + Fence * Silvi +Fertilized:Silvi +(1|Site)+(1|Fertilized:Site)+(1|Fence:Site)+(1|Silvi:Site), data = AR18.TRT[which(is.na(AR18.TRT$Fertilized)==F),], family=binomial, glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1000000)))
  anova(mod.full2,mod.INT1) #fert x fence p = 0.03
  mod.INT2<-glmer(Competitive ~ Fertilized * Fence + Silvi +Fertilized:Silvi +(1|Site)+(1|Fertilized:Site)+(1|Fence:Site)+(1|Silvi:Site), data = AR18.TRT[which(is.na(AR18.TRT$Fertilized)==F),], family=binomial, glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1000000)))
  anova(mod.full2,mod.INT2) #fence x silvi p = 0.004
  mod.INT3<-glmer(Competitive ~ Fertilized * Fence + Fence * Silvi +(1|Site)+(1|Fertilized:Site)+(1|Fence:Site)+(1|Silvi:Site), data = AR18.TRT[which(is.na(AR18.TRT$Fertilized)==F),], family=binomial, glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1000000)))
  anova(mod.full2, mod.INT3) #fert x silvi p = 0.73
  
  # Fert x fence and fence x silvi interactions are both significant. Do both hold up when compared to models with single interactions?
  mod.cand1<-glmer(Competitive ~ Fertilized * Fence + Silvi +(1|Site)+(1|Fertilized:Site)+(1|Fence:Site)+(1|Silvi:Site), data = AR18.TRT[which(is.na(AR18.TRT$Fertilized)==F),], family=binomial, glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1000000)))
  anova(mod.INT3,mod.cand1) #fence x silvi p = 0.002
  mod.cand2<-glmer(Competitive ~ Fertilized + Fence * Silvi +(1|Site)+(1|Fertilized:Site)+(1|Fence:Site)+(1|Silvi:Site), data = AR18.TRT[which(is.na(AR18.TRT$Fertilized)==F),], family=binomial, glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1000000)))
  anova(mod.INT3,mod.cand2) #fence x fert p = 0.02
  
  mod.best<-mod.INT3
  Anova(mod.best) #all terms included are significant, except silvi
  summary(glht(mod.best))
  exp(summary(mod.best)$coefficients[,1:2])
  cbind(exp(summary(mod.best)$coefficients[,"Estimate"]),
        exp(summary(mod.best)$coefficients[,"Std. Error"]),
        summary(mod.best)$coefficients[,"z value"])
  
  cc <- confint(glht(mod.best, parm="beta_",method="Wald"))  ## Wald confidence intervals for fixed effects
  cc$confint
  ctab <- cbind(est=fixef(mod.best),se = summary(mod.best)$coefficients[,"Std. Error"],
                z = summary(mod.best)$coefficients[,"z value"],cc$confint[,2:3]) 
  round(ctab,3)
  exp(ctab)[,-3]
  
  cont.mat3<- rbind("Fert vs Unfert"  = c(0,1,0, 0,0,0, 0,0),
                    "Fence vs NF"     = c(0,0,1, 0,0,0, 0,0),
                    "TH vs MR"        = c(0,0,0, 1,0,0, 0,0),
                    "THMR vs MR"      = c(0,0,0, 0,1,0, 0,0),
                    "THMR vs TH"      = c(0,0,0,-1,1,0, 0,0),
                    "Fnc:TH vs Fnc:MR"= c(0,0,0, 0,0,0, 1,0),
                    "Fnc:SW vs Fnc:MR"= c(0,0,0, 0,0,0, 0,1),
                    "Fnc:SW vs Fnc:TH"= c(0,0,0, 0,0,0,-1,1),
                    "F:F vs F:NF"     = c(0,0,0, 0,0,1, 0,0))
  
  confint(glht(mod.best, linfct=cont.mat3))
  summary(glht(mod.best, linfct=cont.mat3))
  
  # Computing predicted probabilities
  ## for competitiveness of ALL PLANTED oaks
  newdata <- with(AR18.TRT, expand.grid(Fertilized=unique(Fertilized[which(is.na(Fertilized)==F)]),Silvi=unique(Silvi), Fence=unique(Fence),Site=unique(Site)))
  newdata$pred<- predict(mod.best,newdata,re.form=NA, type="response") #predicted probabilities of competitiveness for each treatment combination
  newdata.nosite<-newdata[1:12,c(1:3,5)]#predicted probabilities of competitiveness for each treatment combination
  
  pred.ordered<-newdata.nosite[order(newdata.nosite$Fence, newdata.nosite$Silvi,newdata.nosite$Fertilized),]
  pred.plot1<-rbind(pred.ordered$pred[1:8],pred.ordered$pred[9:16])
  cbind(pred.ordered[,1:3],round(pred.ordered[,4],3))
  barplot(pred.plot1,beside = T)
  
  

#### Height of Surviving Planted Oaks ####
  head(AR18)
  
  str(AR18) #check that predictors are formatted correctly
  AR18$Plot<-as.factor(AR18$Plot)
  AR18$Fence<-as.factor(AR18$Fence)
  AR18$Fertilized<-as.factor(AR18$Fertilized)
  AR18$Alive<-as.factor(AR18$Alive)
  str(AR18)
  
  summary(AR18) #check site totals: Knapp 450, McKinney 793, NS 800, Wulfman 800
  
  AR18.alive<-AR18[which(AR18$Alive==1),]
  summary(AR18.alive)
  length(AR18$Alive[which(AR18$Site=="Nelson-Stokes"&AR18$Alive==1)]) #check total for Nelson Stokes
  
  mean.heights<-aggregate(AR18.alive$Height.cm, by=list(AR18.alive$Fertilized,AR18.alive$Silvi,AR18.alive$Site,AR18.alive$Fence), FUN = mean)
  mean.heights[mean.heights$Group.3=="Nelson-Stokes",]
  names(mean.heights)<-c("Fert","Silvi","Site","Fence","MeanHeight")
  mean.heights2<-cbind.data.frame(mean.heights["Site"], mean.heights["Silvi"], mean.heights["Fence"],mean.heights["Fert"],mean.heights["MeanHeight"])
  
  
  psych::describeBy(AR18.alive$Height.cm, group=list(AR18.alive$Silvi))
  aggregate(AR18.alive$Height.cm, by=list(AR18.alive$Silvi, AR18.alive$Fence, AR18.alive$Fertilized), FUN=length)
  
  #### Mixed models for Height ### 
 
  hist(AR18.alive$Height.cm)
  hist(log(AR18.alive$Height.cm+1)) #log transformation improves distribution
  #added constant is ~ equivalent to 1 cm
  
  #Fit full fixed effects structure (all two-way interactions) and sort through RE structure ####
  lmm.height.full<-lmer(log(Height.cm+1) ~ (Fertilized + Fence + Silvi)^2 + (1|Site)+(1|Fertilized:Site)+(1|Fence:Site)+(1|Silvi:Site), data = AR18.alive, REML=F, lmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1000000)))
  lmm.height.full.rint<-lmer(log(Height.cm+1) ~ (Fertilized + Fence + Silvi)^2 + (1|Site), data = AR18.alive, REML=F, lmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1000000)))
  anova(lmm.height.full,lmm.height.full.rint)
  
  #random coefficients improve model significantly, KEEP 'EM!!!
  # chi square with 3 df = 16.2 (p=0.001) --> keep as a group
  
  plot(lmm.height.full)
  hist(residuals(lmm.height.full))
  
  #test interaction terms by dropping them individually out of model
  lmm.Ln_height.2intA<-lmer(log(Height.cm+1) ~ Fertilized*Fence+Silvi+Fertilized:Silvi+ (1|Site)+(1|Fertilized:Site)+(1|Fence:Site)+(1|Silvi:Site), data = AR18.alive, REML=F, lmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1000000)))
  anova(lmm.height.full,lmm.Ln_height.2intA) #fence x silvi p = 0.23
  lmm.Ln_height.2intB<-lmer(log(Height.cm+1) ~ Fertilized+Fence*Silvi+Fertilized:Silvi+ (1|Site)+(1|Fertilized:Site)+(1|Fence:Site)+(1|Silvi:Site), data = AR18.alive, REML=F, lmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1000000)))
  anova(lmm.height.full,lmm.Ln_height.2intB) #fert x fence p=0.18
  lmm.Ln_height.2intC<-lmer(log(Height.cm+1) ~ Fertilized*Fence+Silvi*Fence+ (1|Site)+(1|Fertilized:Site)+(1|Fence:Site)+(1|Silvi:Site), data = AR18.alive, REML=F, lmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1000000)))
  anova(lmm.height.full,lmm.Ln_height.2intC) #fert x silvi p=0.046
  
  #only dropped interactions term that changed model significantly was silvi x fert
  
  lmm.height.cand1<-lmer(log(Height.cm+1)~Fertilized+Fence*Silvi+Fertilized:Silvi+ (1|Site)+(1|Fertilized:Site)+(1|Fence:Site)+(1|Silvi:Site), data=AR18.alive,REML=F,lmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1000000)))
  lmm.height.cand2<-lmer(log(Height.cm+1)~Fertilized*Fence+Silvi+Fertilized:Silvi+ (1|Site)+(1|Fertilized:Site)+(1|Fence:Site)+(1|Silvi:Site), data=AR18.alive,REML=F,lmerControl(optimizer = "nlminbw", optCtrl=list(maxfun=1000000)))
  lmm.height.cand3<-lmer(log(Height.cm+1)~Fertilized+Fence+Silvi+Fertilized:Silvi+ (1|Site)+(1|Fertilized:Site)+(1|Fence:Site)+(1|Silvi:Site), data=AR18.alive,REML=F,lmerControl(optimizer = "nlminbw", optCtrl=list(maxfun=1000000)))
  
  anova(lmm.height.cand1,lmm.height.cand3) #p = 0.25
  anova(lmm.height.cand2,lmm.height.cand3) #p = 0.23
  
  
  lmm.height.add<-lmer(log(Height.cm+1)~Fertilized+Fence+Silvi+ (1|Site)+(1|Fertilized:Site)+(1|Fence:Site)+(1|Silvi:Site), data=AR18.alive,REML=F,lmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1000000)))
  anova(lmm.height.cand3,lmm.height.add) #when compared to additive model, interaction is still significant
  
  #now fit with REML
  lmm.height.best<-lmer(log(Height.cm+1)~Fertilized+Fence+Silvi+Fertilized:Silvi+ (1|Site)+(1|Fertilized:Site)+(1|Fence:Site)+(1|Silvi:Site), data=AR18.alive,REML=T,lmerControl(optimizer = "nlminbw", optCtrl=list(maxfun=1000000)))
  plot(lmm.height.best)
  par(mfrow=c(1,1));hist(residuals(lmm.height.best))
  summary(lmm.height.best)
  cont.mat<-rbind("MR vs Control"              = c(0,0,0,1, 0, 0,0, 0, 0),
                  "TH vs Control"              = c(0,0,0,0, 1, 0,0, 0, 0),
                  "SW vs Control"              = c(0,0,0,0, 0, 1,0, 0, 0),
                  "MR vs TH"                   = c(0,0,0,1,-1, 0,0, 0, 0),
                  "MR vs SW"                   = c(0,0,0,1, 0,-1,0, 0, 0),
                  "TH vs SW"                   = c(0,0,0,0, 1,-1,0, 0, 0),
                  "Fert effect"                = c(0,1,0,0, 0, 0,0, 0, 0),
                  "Fence effect"               = c(0,0,1,0, 0, 0,0, 0, 0),
                  "Fert Int: MR vs Control"    = c(0,0,0,0, 0, 0,1, 0, 0),
                  "Fert Int: TH vs Control"    = c(0,0,0,0, 0, 0,0, 1, 0),
                  "Fert Int: SW vs Control"    = c(0,0,0,0, 0, 0,0, 0, 1),
                  "Fert Int: MR vs TH"         = c(0,0,0,0, 0, 0,1,-1, 0),
                  "Fert Int: MR vs SW"         = c(0,0,0,0, 0, 0,1, 0,-1),
                  "Fert Int: TH vs SW"         = c(0,0,0,0, 0, 0,0, 1,-1))
  
  #confint(lmm.height.best)
  cbind(round(summary(lmm.height.best)$coefficients,3),
        round(confint(glht(lmm.height.best, method="Wald"))$confint[,2:3],3))
  summary(glht(lmm.height.best,cont.mat))
  
  Anova(lmm.height.best)
  summary(lmm.height.best)
  #AR18.alive[which(AR18.alive$Silvi=="Control"),]

#### GLD of surviving oaks ####
  head(AR18)
  
  str(AR18) #check that predictors are formatted correctly
  AR18$Plot<-as.factor(AR18$Plot)
  AR18$Fence<-as.factor(AR18$Fence)
  AR18$Fertilized<-as.factor(AR18$Fertilized)
  AR18$Alive<-as.factor(AR18$Alive)
  str(AR18)
  
  summary(AR18) #check site totals: Knapp 450, McKinney 793, NS 800, Wulfman 800
  
  AR18.alive<-AR18[which(AR18$Alive==1),]
  summary(AR18.alive)
  length(AR18$Alive[which(AR18$Site=="Nelson-Stokes"&AR18$Alive==1)]) #check total for Nelson Stokes
  
  mean.gld<-aggregate(AR18.alive$GLD.mm[which(is.na(AR18.alive$GLD.mm)==F)], by=list(AR18.alive$Fertilized[which(is.na(AR18.alive$GLD.mm)==F)],AR18.alive$Silvi[which(is.na(AR18.alive$GLD.mm)==F)],AR18.alive$Site[which(is.na(AR18.alive$GLD.mm)==F)],AR18.alive$Fence[which(is.na(AR18.alive$GLD.mm)==F)]), 
                      FUN = mean) #a missing datapoint was messing up aggregate function, hence is.na() command
  mean.gld[mean.gld$Group.3=="Nelson-Stokes",]
  names(mean.gld)<-c("Fert","Silvi","Site","Fence","MeanGLD")
  mean.gld2<-cbind.data.frame(mean.gld["Site"], mean.gld["Silvi"], mean.gld["Fence"],mean.gld["Fert"],mean.gld["MeanGLD"])
  
  psych::describeBy(AR18.alive$GLD.mm, group=AR18.alive$Silvi)
  0.67/0.49
  0.78/0.49
  
  #### Mixed Effects Models FOR GLD ###

  min(AR18.alive$GLD.mm[which(is.na(AR18.alive$GLD.mm)==F)]) #= 0.11
  
  ##need to run AllFit code at bottom of document before running these lines##
  lmm.gld.full<-lmer(log(GLD.mm+1) ~ (Fertilized + Fence + Silvi)^2 + (1|Site)+(1|Fertilized:Site)+(1|Fence:Site)+(1|Silvi:Site), data = AR18.alive, REML=F,  lmerControl(optimizer = "nlminbw", optCtrl=list(maxfun=1000000))) #all 2-way interactions, all random effects
  plot(lmm.gld.full)
  hist(residuals(lmm.gld.full))
  
  lmm.gld.full.rint<-lmer(log(GLD.mm+1) ~ (Fertilized + Fence + Silvi)^2 + (1|Site), data = AR18.alive, REML=F,  lmerControl(optimizer = "nlminbw", optCtrl=list(maxfun=1000000))) #all 2-way interactions, random intercept only
  plot(lmm.gld.full.rint)
  hist(residuals(lmm.gld.full.rint))
  anova(lmm.gld.full,lmm.gld.full.rint) #keep random coefficients
  
  #now check interaction terms
  
  lmm.gld.INT1<-lmer(log(GLD.mm+1) ~ Fertilized + Fence * Silvi + Fertilized:Silvi + (1|Site)+(1|Fertilized:Site)+(1|Fence:Site)+(1|Silvi:Site), data = AR18.alive, REML=F,  lmerControl(optimizer = "nlminbw", optCtrl=list(maxfun=1000000)))
  anova(lmm.gld.full,lmm.gld.INT1) #FertXFence not signif
  lmm.gld.INT2<-lmer(log(GLD.mm+1) ~ Fertilized * Fence + Silvi + Fertilized:Silvi + (1|Site)+(1|Fertilized:Site)+(1|Fence:Site)+(1|Silvi:Site), data = AR18.alive, REML=F,  lmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1000000))) 
  anova(lmm.gld.full,lmm.gld.INT2) #FenceXSilvi not signif
  lmm.gld.INT3<-lmer(log(GLD.mm+1) ~ Fertilized * Fence + Silvi + Fence:Silvi + (1|Site)+(1|Fertilized:Site)+(1|Fence:Site)+(1|Silvi:Site), data = AR18.alive, REML=F,  lmerControl(optimizer = "nlminbw", optCtrl=list(maxfun=1000000))) 
  anova(lmm.gld.full, lmm.gld.INT3) #FertXSilvi marginally significant (p = 0.096)
  #compare model with fert X silvi interaction to additive model
  
  lmm.gld.cand1<-lmer(log(GLD.mm+1) ~ Fertilized + Fence + Silvi + Fertilized:Silvi + (1|Site)+(1|Fertilized:Site)+(1|Fence:Site)+(1|Silvi:Site), data = AR18.alive, REML=F,  lmerControl(optimizer = "nlminbw", optCtrl=list(maxfun=1000000))) 
  lmm.gld.add<-lmer(log(GLD.mm+1) ~ Fertilized + Fence + Silvi + (1|Site)+(1|Fertilized:Site)+(1|Fence:Site)+(1|Silvi:Site), data = AR18.alive, REML=F,  lmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1000000)))
  anova(lmm.gld.cand1,lmm.gld.add) #p = 0.11, exclude from model. Use additive effects only.
  
  lmm.gld.best<-lmer(log(GLD.mm+1) ~ Fertilized + Fence + Silvi + (1|Site)+(1|Fertilized:Site)+(1|Fence:Site)+(1|Silvi:Site), data = AR18.alive, REML=T,  lmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1000000)))
  
  plot(lmm.gld.best) #not perfect, but probably acceptable
  hist(residuals(lmm.gld.best)) #looks good
  
  Anova(lmm.gld.best)
  rsquared(lmm.gld.best)
  
  #summary(glht(lmm.gld.best))
  
  cbind.data.frame(round(summary(lmm.gld.best)$coefficients,3),
                   round(confint(glht(lmm.gld.best,method="Wald"))$confint[,2:3],3))
  
  cont.mat<-rbind("Fert"=c(0,1,0,0,0,0),
                  "Fence"=c(0,0,1,0,0,0),
                  "MR vs Control"=c(0,0,0,1,0,0),
                  "TH vs Control" = c(0,0,0,0,1,0),
                  "TH+MR vs Control"=c(0,0,0,0,0,1),
                  "MR vs TH" = c(0,0,0,1,-1,0),
                  "MR vs MR+TH"=c(0,0,0,1,0,-1),
                  "TH vs MR+TH"= c(0,0,0,0,1,-1))
  
  summary(glht(lmm.gld.best,linfct=cont.mat))  # adjusted p-values for treatment effects and their comparisons
  
  ### create barplot ####
  mean.gld.all<-aggregate(AR18.alive$GLD.mm[which(is.na(AR18.alive$GLD.mm)==F)], 
                          by=list(AR18.alive$Fertilized[which(is.na(AR18.alive$GLD.mm)==F)],AR18.alive$Silvi[which(is.na(AR18.alive$GLD.mm)==F)],AR18.alive$Fence[which(is.na(AR18.alive$GLD.mm)==F)]),
                          FUN = mean)
  names(mean.gld.all)<-c("Fert","Silvi","Fence","Meangld")
  mean.gld.all2<-cbind.data.frame(mean.gld.all["Silvi"], mean.gld.all["Fence"],mean.gld.all["Fert"],mean.gld.all["Meangld"])
  
  mean.gld.all<-rbind(c(mean.gld.all2$Meangld[which(mean.gld.all2$Fence==0)][1],0,mean.gld.all2$Meangld[which(mean.gld.all2$Fence==0)][2:7]),
                      mean.gld.all2$Meangld[which(mean.gld.all2$Fence==1)]) 
  
  SD.gld.all<-aggregate(AR18.alive$GLD.mm[which(is.na(AR18.alive$GLD.mm)==F)], 
                        by=list(AR18.alive$Fertilized[which(is.na(AR18.alive$GLD.mm)==F)],AR18.alive$Silvi[which(is.na(AR18.alive$GLD.mm)==F)],AR18.alive$Fence[which(is.na(AR18.alive$GLD.mm)==F)]), 
                        FUN = sd)
  
  ## SD for unfenced, unfertilized, control = 0, since there were 3 surviving seedlings in that group, all with gld = 7mm
  
  names(SD.gld.all)<-c("Fert","Silvi","Fence","SDgld")
  
  SD.gld.all$SEgld<-NA
  
  for( i in 1:nrow(SD.gld.all) ){
    SD.gld.all$SEgld[i]<-SD.gld.all$SDgld[i]/sqrt(length(AR18.alive$GLD.mm[which(AR18.alive$Fertilized==SD.gld.all$Fert[i]&AR18.alive$Silvi==SD.gld.all$Silvi[i]&AR18.alive$Fence==SD.gld.all$Fence[i])]))
  }
  
  SE.gld.all<-rbind(c(SD.gld.all$SEgld[which(SD.gld.all$Fence==0)][1],0,SD.gld.all$SEgld[which(SD.gld.all$Fence==0)][2:7]),
                    SD.gld.all$SEgld[which(SD.gld.all$Fence==1)])
  Trt.names<-c("Control NoFert","Control Fert", "MR NoFert", "MR Fert", "TH NoFert", "TH Fert", "TH+MR NoFert","TH+MR Fert")  
  rownames(mean.gld.all)<-c("Unfenced","Fenced")
  colnames(mean.gld.all)<-Trt.names
  
  
  
#### FIGURE 3 PLOTTING CODE ####
# read dataset back in just in case formatting got wonky #
AR18<-read.csv("Artificial Regen 2018.csv")
  AR18$Height.Ft<-NULL #dropped column with superflous original data (height measured in feet)
  AR18$Notes<-NULL  #drop notes column
  AR18$Date<-NULL  #drop date column
  AR18$X<-NULL #other notes
  
  ##survival
  tot.surv1<-aggregate(as.numeric(AR18$Alive), by=list(AR18$Fertilized,AR18$Silvi,AR18$Site,AR18$Fence), FUN = sum)
  names(tot.surv1)<-c("Fert","Silvi","Site","Fence","Survived")
  tot.surv.fert<-cbind.data.frame(tot.surv1["Site"], tot.surv1["Silvi"], tot.surv1["Fence"],tot.surv1["Fert"],tot.surv1["Survived"])
  tot.surv.fert$Planted<-c(50,50,50,50,50,50, 50,50,49,50,50,50,50,50, 50,50,50,50,50,50,50,50, 50,50,50,50,50,50,50,50,
                           50,50,50,50, 50,50,51,50,50,50,46,46, 50,50,50,50,50,50,50,50, 50,50,50,50,50,50,50,50)
  tot.surv.fert$Prop.surv<-tot.surv.fert$Survived/tot.surv.fert$Planted
  
  aggregate(tot.surv.fert$Prop.surv, by=list(tot.surv.fert$Silvi,tot.surv.fert$Fence,tot.surv.fert$Fert), FUN=mean)
  aggregate(tot.surv.fert$Prop.surv, by=list(tot.surv.fert$Silvi,tot.surv.fert$Fence), FUN=mean)
  
  summary(tot.surv.fert)
  
  plant.sum<-aggregate(tot.surv.fert$Planted, by=list(tot.surv.fert$Fert,tot.surv.fert$Silvi,tot.surv.fert$Fence), FUN=sum)
  names(plant.sum)<-c("Fert","Silvi","Fence","Planted")
  
  surv.sum<-aggregate(as.numeric(AR18$Alive),by=list(AR18$Fertilized,AR18$Silvi,AR18$Fence),FUN=sum)
  surv.sum<-cbind.data.frame(surv.sum,plant.sum[,4])
  names(surv.sum)<-c("Fert","Silvi","Fence","Survived","Planted")
  surv.sum$proportion = with(surv.sum, Survived/(Planted))
  
  surv.forPlot<-rbind(surv.sum$proportion[1:8],surv.sum$proportion[9:16])
  
  surv.sd<-aggregate(tot.surv.fert$Prop.surv, by=list(tot.surv.fert$Fence,tot.surv.fert$Fert,tot.surv.fert$Silvi), FUN=sd)
  names(surv.sd)=c("Fence","Fert","Silvi","SE")
  surv.sd$n.site<-c(4,3,4,3,4,4,4,4,3,3,3,3,4,4,4,4)
  surv.se<-surv.sd[,4]/sqrt(surv.sd$n.site)
  
  
  ## Competitiveness 
  tot.comp1<-aggregate(AR18.alive$Competitive, by=list(AR18.alive$Fertilized,AR18.alive$Silvi,AR18.alive$Site,AR18.alive$Fence), FUN = sum)
  names(tot.comp1)<-c("Fert","Silvi","Site","Fence","Competitive")
  tot.comp.fert.<-cbind.data.frame(tot.comp1["Site"], tot.comp1["Silvi"], tot.comp1["Fence"],tot.comp1["Fert"],tot.comp1["Competitive"])
  nullrows<-rbind.data.frame(c("Knapp","Control",0,0,0),
                             c("Knapp","Control",0,1,0),
                             c("McKinney","Control",0,1,0),
                             c("Nelson-Stokes","Control",0,0,0),
                             c("Nelson-Stokes","Control",0,1,0),
                             c("Wulfman","Control",0,1,0))
  colnames(nullrows)<-names(tot.comp.fert.)
  str(nullrows)
  nullrows$Competitive<-as.numeric(nullrows$Competitive)
  str(tot.comp.fert.)
  tot.comp.fert.$Fence<-as.factor(tot.comp.fert.$Fence)
  tot.comp.fert<-rbind.data.frame(nullrows[1:2,],tot.comp.fert.[1:5,],nullrows[3,],tot.comp.fert.[6:11,],
                                  nullrows[4:5,],tot.comp.fert.[12:18,],nullrows[6,],tot.comp.fert.[19:52,])
  
  tot.comp.fert$Planted<-c(50,50,50,50,50,50, 50,50,49,50,50,50,50,50, 50,50,50,50,50,50,50,50, 50,50,50,50,50,50,50,50,
                           50,50,50,50, 50,50,51,50,50,50,46,46, 50,50,50,50,50,50,50,50, 50,50,50,50,50,50,50,50)
  
  tot.comp.fert$Prop.comp<-tot.comp.fert$Competitive/tot.comp.fert$Planted
  
  
  AR18$Competitive<-NA
  for(i in 1:nrow(AR18)){
    if(AR18$Alive[i]==0){
      AR18$Competitive[i]=0}else{
        if(AR18$Crown.Class[i]=="D"){
          AR18$Competitive[i]=1}else{
            if(AR18$Crown.Class[i]=="C"){
              AR18$Competitive[i]=1}else{
                if(AR18$Crown.Class[i]!="S"&AR18$Comp[i]==0&AR18$Height.cm[i]>100){
                  AR18$Competitive[i]=1}else{
                    AR18$Competitive[i]=0}}}}}
  
  comp.sum.<-aggregate(as.numeric(AR18.alive$Competitive),by=list(AR18.alive$Fertilized,AR18.alive$Silvi,AR18.alive$Fence),FUN=sum)
  comp.sum<-rbind.data.frame(comp.sum.[1,],c(1,"Control",0,0),comp.sum.[2:15,])
  names(comp.sum)<-c("Fert","Silvi","Fence","Competitive")
  comp.sum$Competitive<-as.numeric(comp.sum$Competitive)
  
  plant.sum<-aggregate(tot.comp.fert$Planted, by=list(tot.comp.fert$Fert,tot.comp.fert$Silvi,tot.comp.fert$Fence), FUN=sum)
  names(plant.sum)<-c("Fert","Silvi","Fence","Planted")
  comp.prop<-comp.sum$Competitive/plant.sum$Planted
  comp.forPlot<-rbind(comp.prop[1:8],comp.prop[9:16])
  
  comp.sd<-aggregate(tot.comp.fert$Prop.comp, by=list(tot.comp.fert$Fence,tot.comp.fert$Fert,tot.comp.fert$Silvi), FUN=sd)
  names(comp.sd)=c("Fence","Fert","Silvi","SE")
  comp.sd$n.site<-c(4,3,4,3,4,4,4,4,3,3,3,3,4,4,4,4)
  comp.se<-comp.sd[,4]/sqrt(comp.sd$n.site)
  
  
  ##heights   
  AR18.alive<-AR18[which(AR18$Alive==1),]
  summary(AR18.alive)
  length(AR18$Alive[which(AR18$Site=="Nelson-Stokes"&AR18$Alive==1)]) #check total for Nelson Stokes
  
  #AR18.alive$Height.cm<-AR18.alive$Height.cm*0.0328084
  mean.heights<-aggregate(AR18.alive$Height.cm, by=list(AR18.alive$Fertilized,AR18.alive$Silvi,AR18.alive$Site,AR18.alive$Fence), FUN = mean)
  mean.heights[mean.heights$Group.3=="Nelson-Stokes",]
  names(mean.heights)<-c("Fert","Silvi","Site","Fence","MeanHeight")
  mean.heights2<-cbind.data.frame(mean.heights["Site"], mean.heights["Silvi"], mean.heights["Fence"],mean.heights["Fert"],mean.heights["MeanHeight"])
  
  mean.heights.all<-aggregate(AR18.alive$Height.cm, by=list(AR18.alive$Fertilized,AR18.alive$Silvi,AR18.alive$Fence), FUN = mean)
  names(mean.heights.all)<-c("Fert","Silvi","Fence","MeanHeight")
  mean.heights.all2<-cbind.data.frame(mean.heights.all["Silvi"], mean.heights.all["Fence"],mean.heights.all["Fert"],mean.heights.all["MeanHeight"])
  
  mean.ht.all<-rbind(c(mean.heights.all2$MeanHeight[which(mean.heights.all2$Fence==0)][1],0,mean.heights.all2$MeanHeight[which(mean.heights.all2$Fence==0)][2:7]),
                     mean.heights.all2$MeanHeight[which(mean.heights.all2$Fence==1)]) 
  
  SD.heights.all<-aggregate(AR18.alive$Height.cm, by=list(AR18.alive$Fertilized,AR18.alive$Silvi,AR18.alive$Fence), FUN = sd)
  names(SD.heights.all)<-c("Fert","Silvi","Fence","SDHeight")
  
  SD.heights.all$SEHeight<-NA
  
  for( i in 1:nrow(SD.heights.all) ){
    SD.heights.all$SEHeight[i]<-SD.heights.all$SDHeight[i]/sqrt(length(AR18.alive$Height.cm[which(AR18.alive$Fertilized==SD.heights.all$Fert[i]&AR18.alive$Silvi==SD.heights.all$Silvi[i]&AR18.alive$Fence==SD.heights.all$Fence[i])]))
  }
  
  SE.ht.all<-rbind(c(SD.heights.all$SEHeight[which(SD.heights.all$Fence==0)][1],0,SD.heights.all$SEHeight[which(SD.heights.all$Fence==0)][2:7]),
                   SD.heights.all$SEHeight[which(SD.heights.all$Fence==1)])
  Trt.names<-c("Control NoFert","Control Fert", "MR NoFert", "MR Fert", "TH NoFert", "TH Fert", "TH+MR NoFert","TH+MR Fert")  
  rownames(mean.ht.all)<-c("Unfenced","Fenced")
  colnames(mean.ht.all)<-Trt.names
  
  ##GLD 
  mean.gld<-aggregate(AR18.alive$GLD.mm[which(is.na(AR18.alive$GLD.mm)==F)], by=list(AR18.alive$Fertilized[which(is.na(AR18.alive$GLD.mm)==F)],AR18.alive$Silvi[which(is.na(AR18.alive$GLD.mm)==F)],AR18.alive$Site[which(is.na(AR18.alive$GLD.mm)==F)],AR18.alive$Fence[which(is.na(AR18.alive$GLD.mm)==F)]), 
                      FUN = mean) #a missing datapoint was messing up aggregate function, hence is.na() command
  mean.gld[mean.gld$Group.3=="Nelson-Stokes",]
  names(mean.gld)<-c("Fert","Silvi","Site","Fence","MeanGLD")
  mean.gld2<-cbind.data.frame(mean.gld["Site"], mean.gld["Silvi"], mean.gld["Fence"],mean.gld["Fert"],mean.gld["MeanGLD"])
  
  mean.gld.all<-aggregate(AR18.alive$GLD.mm[which(is.na(AR18.alive$GLD.mm)==F)], 
                          by=list(AR18.alive$Fertilized[which(is.na(AR18.alive$GLD.mm)==F)],AR18.alive$Silvi[which(is.na(AR18.alive$GLD.mm)==F)],AR18.alive$Fence[which(is.na(AR18.alive$GLD.mm)==F)]),
                          FUN = mean)
  names(mean.gld.all)<-c("Fert","Silvi","Fence","Meangld")
  mean.gld.all2<-cbind.data.frame(mean.gld.all["Silvi"], mean.gld.all["Fence"],mean.gld.all["Fert"],mean.gld.all["Meangld"])
  
  mean.gld.all<-rbind(c(mean.gld.all2$Meangld[which(mean.gld.all2$Fence==0)][1],0,mean.gld.all2$Meangld[which(mean.gld.all2$Fence==0)][2:7]),
                      mean.gld.all2$Meangld[which(mean.gld.all2$Fence==1)]) 
  
  SD.gld.all<-aggregate(AR18.alive$GLD.mm[which(is.na(AR18.alive$GLD.mm)==F)], 
                        by=list(AR18.alive$Fertilized[which(is.na(AR18.alive$GLD.mm)==F)],AR18.alive$Silvi[which(is.na(AR18.alive$GLD.mm)==F)],AR18.alive$Fence[which(is.na(AR18.alive$GLD.mm)==F)]), 
                        FUN = sd)
  
  ## SD for unfenced, unfertilized, control = 0, since there were 3 surviving seedlings in that group, all with gld = 7mm
  
  names(SD.gld.all)<-c("Fert","Silvi","Fence","SDgld")
  
  SD.gld.all$SEgld<-NA
  
  for( i in 1:nrow(SD.gld.all) ){
    SD.gld.all$SEgld[i]<-SD.gld.all$SDgld[i]/sqrt(length(AR18.alive$GLD.mm[which(AR18.alive$Fertilized==SD.gld.all$Fert[i]&AR18.alive$Silvi==SD.gld.all$Silvi[i]&AR18.alive$Fence==SD.gld.all$Fence[i])]))
  }
  
  SE.gld.all<-rbind(c(SD.gld.all$SEgld[which(SD.gld.all$Fence==0)][1],0,SD.gld.all$SEgld[which(SD.gld.all$Fence==0)][2:7]),
                    SD.gld.all$SEgld[which(SD.gld.all$Fence==1)])
  Trt.names<-c("Control NoFert","Control Fert", "MR NoFert", "MR Fert", "TH NoFert", "TH Fert", "TH+MR NoFert","TH+MR Fert")  
  rownames(mean.gld.all)<-c("Unfenced","Fenced")
  colnames(mean.gld.all)<-Trt.names
  
  
  setwd("~/Library/Mobile Documents/com~apple~CloudDocs/Purdue PC/TNC Oak Project/TNC Forests Submission/Forests Figs")
  tiff(filename="Forests Fig. 3_Artificial Regen.tiff",width=6.5,height=7,units="in",res=400, pointsize=8,
       compression = "lzw")  
  
  #==== Plot Total Survival===
  
  par(mar=c(4,6,3,1)+0.1, bg=NA, mfrow=c(2,2), ps=9
      #,oma=c(2,2,0,0)
  )
  bplot.surv<-barplot(surv.forPlot, beside=T, xaxt="n", las=1,ylim=c(0,1), col = c("lightgray","gray20"), 
                      angle=45, density=rep(c(45,45,1000,1000),4), space = rep(c(1.5,0,0.5,0),4))
  abline(h=0)
  
  l_ply(seq_along(bplot.surv), function(x) arrows(x0 = bplot.surv[x], y0=as.matrix(surv.forPlot)[x]-as.matrix(surv.se)[x],x1=bplot.surv[x],
                                                  y1=as.matrix(surv.forPlot)[x]+as.matrix(surv.se)[x], code=3,length=0.03,angle=90,lwd=1))      
  mtext(side=2, line=4, text="Seedling Survival", cex=1)
  #mtext(side=1, line=0.8, at=c(-1,seq(2,23,by=3)),text=c("Fert:", rep(c("N","Y"),4)))  
  mtext(side=1, line=1, at=seq(3.75,21.75,by=6), text = c("Control","MR","TH","SW"))
  
  text(x=2, y=0.95*1, labels = "(a)",cex=1)
  #legend("topleft", cex=1, inset = c(0.02,0.00),legend = c("Unfenced", "Fenced"), fill= c("indianred4","lightgoldenrod3"))
  
  ## Competitiveness =====
  #==== Plot Total competitiveness (of all planted oaks)====
  bplot.comp<-barplot(comp.forPlot, beside=T, xaxt="n", las=1, ylim=c(0,1), col = c("lightgray","gray20"), 
                      angle=45, density=rep(c(45,45,1000,1000),4), space = rep(c(1.5,0,0.5,0),4))
  abline(h=0)
  
  l_ply(seq_along(bplot.comp), function(x) arrows(x0 = bplot.comp[x], y0=as.matrix(comp.forPlot)[x]-as.matrix(comp.se)[x],x1=bplot.comp[x],
                                                  y1=as.matrix(comp.forPlot)[x]+as.matrix(comp.se)[x], code=3,length=0.03,angle=90,lwd=1))      
  mtext(side=2, line=4, text="Proportion Competitive Seedlings", cex=1)
  #mtext(side=1, line=0.8, at=c(-1,seq(2,23,by=3)),text=c("Fert:", rep(c("N","Y"),4)))  
  mtext(side=1, line=1, at=seq(3.75,21.75,by=6), text = c("Control","MR","TH","SW"))
  
  text(x=2, y=0.95*1, labels = "(b)",cex=1)
  legend("topright", cex=1, inset = c(0.02,0.00),legend = c("Unfenced + Unfertilized", "Fenced Only","Fertilized Only","Fenced + Fertilized"), 
         fill= c("lightgray","gray20","lightgray","gray20"), angle=45,density=c(45,45,1000,1000), bty="n")
  
  ## Height 
  bplot.height<-barplot(mean.ht.all, beside=T, xaxt="n", las=1,ylim=c(0,300), col = c("lightgray","gray20"), 
                        angle=45, density=rep(c(45,45,1000,1000),4), space = rep(c(1.5,0,0.5,0),4))
  
  abline(h=0)
  
  l_ply(seq_along(bplot.height), function(x) arrows(x0 = bplot.height[x], y0=as.matrix(mean.ht.all)[x]-as.matrix(SE.ht.all)[x],x1=bplot.height[x],
                                                    y1=as.matrix(mean.ht.all)[x]+as.matrix(SE.ht.all)[x], code=3,length=0.03,angle=90,lwd=1))      
  mtext(side=2, line=4, text="Height (cm)", cex=1)
  #mtext(side=1, line=0.8, at=c(-1,seq(2,23,by=3)),text=c("Fert:", rep(c("N","Y"),4)))  
  mtext(side=1, line=1, at=seq(3.5,21.5,by=6), text = c("Control","MR","TH","SW"))
  
  text(x=2, y=0.95*300, labels = "(c)",cex=1)
  # legend("topleft", cex=1, inset = c(0.02,0.00),legend = c("Unfenced", "Fenced"), fill= c("indianred4","lightgoldenrod3"))
  
  ## GLD
  bplot.gld<-barplot(mean.gld.all, beside=T, xaxt="n", las=1,ylim=c(0,30), col = c("lightgray","gray20"), 
                     angle=45, density=rep(c(45,45,1000,1000),4), space = rep(c(1.5,0,0.5,0),4))
  
  abline(h=0)
  
  l_ply(seq_along(bplot.gld), function(x) arrows(x0 = bplot.gld[x], y0=as.matrix(mean.gld.all)[x]-as.matrix(SE.gld.all)[x],x1=bplot.gld[x],
                                                 y1=as.matrix(mean.gld.all)[x]+as.matrix(SE.gld.all)[x], code=3,length=0.03,angle=90,lwd=1))      
  mtext(side=2, line=4, text="Groundline Diameter (mm)", cex=1)
  #mtext(side=1, line=0.8, at=c(-1,seq(2,23,by=3)),text=c("Fert:", rep(c("N","Y"),4)))  
  mtext(side=1, line=1, at=seq(3.5,21.5,by=6), text = c("Control","MR","TH","SW"))
  
  text(x=2, y=0.95*30, labels = "(d)",cex=1)
  #legend("topleft", cex=1, inset = c(0.02,0.00),legend = c("Unfenced", "Fenced"), fill= c("indianred4","lightgoldenrod3"))
  
  
  #end plotting code
  dev.off()   
  
  
### In response to reviewer comment about how browse pressure vaires between sites ###
fencexsite.means<-aggregate(AR18.alive$Height.cm ~ AR18.alive$Fence*AR18.alive$Site, FUN=mean)  
  names(fencexsite.means)<-c("Fence","Site","Height")
  fencexsite.summ<-describeBy(AR18.alive$Height.cm,list(AR18.alive$Fence,AR18.alive$Site))
  fencexsite.se_list<-cbind(fencexsite.summ[[1]]["se"],fencexsite.summ[[2]]["se"],fencexsite.summ[[3]]["se"],fencexsite.summ[[4]]["se"],
                        fencexsite.summ[[5]]["se"],fencexsite.summ[[6]]["se"],fencexsite.summ[[7]]["se"],fencexsite.summ[[8]]["se"])
  
  tiff(filename="Forests Fig.4_Fence Effects by Site.tiff",width=4,height=3.5,units="in",res=400, pointsize=8,
       compression = "lzw")                      
  bplot.sitebrowse<-barplot(fencexsite.means$Height, ylim=c(0,300),space=rep(c(0.2,0.1),4), las=1,
                            col = "gray30", angle=45, density=c(1000,45), ylab="Height (cm)")
    axis(side=1, at=c(0.0,1.25, 3.55, 5.85, 8.15, 9.4), labels = c("","Knapp","McKinney","Nelson-Stokes","Wulfman",""))
    legend("topright",fill = "gray30", angle=45,density=c(1000,45),legend = c("unfenced","fenced"), bty="n")
    l_ply(seq_along(bplot.sitebrowse), function(x) arrows(x0 = bplot.sitebrowse[x], y0=as.matrix(fencexsite.means$Height)[x]-as.matrix(fencexsite.se_list)[x],x1=bplot.sitebrowse[x],
                                                      y1=as.matrix(fencexsite.means$Height)[x]+as.matrix(fencexsite.se_list)[x], code=3,length=0.03,angle=90,lwd=1))      
    dev.off()
#####################################################    
#Allfit####
#run lines to write Allfit function, then run code under line 139 to use the Allfit Function to assess which optimizer function to use
      
      ###All Fit Code====    
      require("optimx")
      require("nloptr")  
      meth.tab.0 <- cbind(optimizer=
                            rep(c("bobyqa",
                                  "Nelder_Mead",
                                  "nlminbw",
                                  "nmkbw",
                                  "optimx",
                                  "nloptwrap" ),
                                c(rep(1,5),2)),
                          method= c(rep("",4), "L-BFGS-B",
                                    "NLOPT_LN_NELDERMEAD", "NLOPT_LN_BOBYQA"))
      
      nlminbw   <- lme4:::nlminbwrap
      namedList <- lme4:::namedList
      
      if (require("dfoptim")) {
        nmkbw <- function(fn,par,lower,upper,control) {
          if (length(par)==1) {
            res <- optim(fn=fn,par=par,lower=lower,upper=100*par,
                         method="Brent")
          } else {
            if (!is.null(control$maxfun)) {
              control$maxfeval <- control$maxfun
              control$maxfun <- NULL
            }
            res <- nmkb(fn=fn,par=par,lower=lower,upper=upper,control=control)
          }
          res$fval <- res$value
          res
        }
      } else { ## pkg{dfoptim} not available
        ## for nmkb
        meth.tab.0 <- meth.tab.0[meth.tab.0[,"optimizer"] != "nmkbw",]
      }
      
      allFit <- function(m, meth.tab = meth.tab.0,
                         data=NULL,
                         verbose=TRUE,
                         maxfun=1e5)
      {
        stopifnot(length(dm <- dim(meth.tab)) == 2, dm[1] >= 1, dm[2] >= 2,
                  is.character(optimizer <- meth.tab[,"optimizer"]),
                  is.character(method    <- meth.tab[,"method"]))
        fit.names <- gsub("\\.$","",paste(optimizer, method, sep="."))
        res <- setNames(as.list(fit.names), fit.names)
        for (i in seq_along(fit.names)) {
          if (verbose) cat(fit.names[i],": ")
          ctrl <- list(optimizer=optimizer[i])
          ctrl$optCtrl <- switch(optimizer[i],
                                 optimx    = list(method   = method[i]),
                                 nloptWrap = list(algorithm= method[i]),
                                 list(maxfun=maxfun))
          ctrl <- do.call(if(isGLMM(m)) glmerControl else lmerControl, ctrl)
          tt <- system.time(rr <- tryCatch(update(m, control = ctrl),
                                           error = function(e) e))
          attr(rr, "optCtrl") <- ctrl$optCtrl # contains crucial info here
          attr(rr, "time") <- tt  # store timing info
          res[[i]] <- rr
          if (verbose) cat("[OK]\n")
        }
        
        structure(res, class = "allfit", fit = m, sessionInfo =  sessionInfo(),
                  data = data # is dropped if NULL
        )
      }
      
      print.allfit <- function(object, width=80, ...) {
        cat("original model:\n")
        f <- attr(object,"fit")
        ss <- function(x) {
          if (nchar(x)>width) {
            strwrap(paste0(substr(x,1,width-3),"..."))
          } else x
        }
        ff <- ss(deparse(formula(f)))
        cat(ff,"\n")
        cat("data: ",deparse(getCall(f)$data),"\n")
        cat("optimizers (",length(object),"): ",
            ss(paste(names(object),collapse=", ")),"\n",
            sep="")
        which.bad <- sapply(object,is,"error")
        if ((nbad <- sum(which.bad))>0) {
          cat(nbad,"optimizers failed\n")
        }
        cat("differences in negative log-likelihoods:\n")
        nllvec <- -sapply(object[!which.bad],logLik)
        print(summary(nllvec-min(nllvec)))
      }
      
      summary.allfit <- function(object, ...) {
        which.OK <- !sapply(object, is, "error")
        objOK <- object[which.OK]
        msgs <- lapply(objOK, function(x) x@optinfo$conv$lme4$messages)
        fixef <- do.call(rbind, lapply(objOK, fixef))
        llik <- sapply(objOK, logLik)
        times <- t(sapply(objOK, attr, "time"))
        feval <- sapply(objOK, function(x) x@optinfo$feval)
        sdcor <- do.call(rbind, lapply(objOK, function(x)
          as.data.frame(VarCorr(x))[, "sdcor"]))
        theta <- do.call(rbind, lapply(objOK,
                                       function(x) getME(x, "theta")))
        cnm <- lme4:::tnames(objOK[[1]])
        if (sigma(object[[1]])!=1) cnm <- c(cnm,"sigma")
        colnames(sdcor) <- unname(cnm)
        sdcor <- as.data.frame(sdcor)
        namedList(which.OK, msgs, fixef, llik, sdcor, theta, times, feval)
      }
      
      
      #assess which optimizer to use with your specific model====
      aa<-allFit(glmer.surv.full_rs)
      is.OK <- sapply(aa,is,"merMod") 
      aa.OK <- aa[is.OK]
      lapply(aa.OK,function(x) x@optinfo$conv$lme4$messages) #models with 'NULL' did not have a convergence error
      (lliks <- sort(sapply(aa.OK,logLik))) #make sure the Loglikelthood for your chosen optimizer is not wacky
      
