## R Code for Naturally Regenerated Oak Saplings ##
## Sampled in 1/100 acre circular plots ##

library(piecewiseSEM)
library(blmeco)
library(multcomp)
library(car)
library(plyr)
library(lme4)   

setwd("~/Library/Mobile Documents/com~apple~CloudDocs/Purdue PC/TNC Oak Project/TNC Forests Submission/Supplementary Materials")

saplings.all<-read.csv("Sapling Table_all years.csv")
  head(saplings.all)
  
sapling<- saplings.all[which(saplings.all$Year==10),]  
  head(sapling)
  
quer_NR<-sapling[,-c(5:41)]
  head(quer_NR)
  
quer_NR$QU.TotNR<-NA
  for(i in 1:nrow(quer_NR)){
    quer_NR$QU.TotNR[i]<-sum(quer_NR$QUAL[i], quer_NR$QUMO[i],quer_NR$QURU[i], quer_NR$QUVE[i])
    
  }
    quer_NR$QU.TotNR #Total naturally regenerated oak saplings in each plot
    
    aggregate(quer_NR$QU.TotNR*25~quer_NR$Silvi, FUN=mean)
    
    hist(quer_NR$QU.TotNR) #probably poisson distributed 
    glm.tot<-glmer(QU.TotNR ~ Silvi + Fence + (1|Site), family=poisson, data=quer_NR)
    glm.tot.ranef<-glmer(QU.TotNR ~ Silvi + Fence + (1|Site) + (1|Silvi:Site) + (1|Fence:Site), family=poisson, data=quer_NR, glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=1000000)))
      anova(glm.tot.ranef,glm.tot) #not a significant improvement, but may as well use the fully parameterized random effect model for consistency
    
      summary(glm.tot.ranef) #similar to effects we were seeing from silvicultural treatments for planted oaks 
        
        Anova(glm.tot.ranef)
        dispersion_glmer(glm.tot.ranef) #close to 1
        rsquared(glm.tot.ranef) #marginal = 0.337, conditional = 0.536
        
        summary(glht(glm.tot.ranef, mcp(Silvi="Tukey")))
        summary(glm.tot.ranef)$coefficients
    
    #glm.tot.full<-glmer(QU.TotNR ~ Silvi * Fence + (1|Site)+ (1|Silvi:Site) + (1|Fence:Site), family=poisson, data=quer_NR, glmerControl(optimizer="bobyqa",optCtrl=list(maxfun=1000000))) #increase max number of iterations and use bobyqa optimizer)
    # not enough oaks to test an interaction term
    
QUAL.means<-aggregate(quer_NR$QUAL, by=list(quer_NR$Fence, quer_NR$Silvi), FUN=mean)
QUMO.means<-aggregate(quer_NR$QUMO, by=list(quer_NR$Fence, quer_NR$Silvi), FUN=mean)$x
QURU.means<-aggregate(quer_NR$QURU, by=list(quer_NR$Fence, quer_NR$Silvi), FUN=mean)$x
QUVE.means<-aggregate(quer_NR$QUVE, by=list(quer_NR$Fence, quer_NR$Silvi), FUN=mean)$x

oak.means.c<-cbind.data.frame(QUAL.means,QUMO.means,QURU.means,QUVE.means)
  names(oak.means.c)<-c("Fence","Silvi","QUAL","QUMO","QURU","QUVE")
    oak.means.HA<-t(oak.means.c[,3:6])*40.4686
    colnames(oak.means.HA)<-paste(oak.means.c$Silvi,oak.means.c$Fence)
  oak.means.sums<-colSums(oak.means.HA)
#oak.mean.silvi<-aggregate(quer_NR$QU.TotNR*40.4686, by=list(quer_NR$Silvi), FUN=mean)
#oak.SE.silvi<-aggregate(quer_NR$QU.TotNR*40.4686, by=list(quer_NR$Silvi), FUN=sd)    
#oak.SE.silvi/sqrt(c(31,32,24,32))
oak.SD<-aggregate(quer_NR$QU.TotNR*(100*0.404686), by=list(quer_NR$Fence, quer_NR$Silvi), FUN=sd)
  oak.SE<-cbind.data.frame(oak.SD[,1:2], oak.SD[,3]/sqrt(c(4,3,4,4,3,3,4,4)))
  oak.SE.vec<-oak.SE[,3]

#Figure for Manuscript
setwd("~/Library/Mobile Documents/com~apple~CloudDocs/Purdue PC/TNC Oak Project/TNC Forests Submission/Forests Figs")
  
tiff(filename="Fig. 5_Forests Oak Saplings.tiff",width=4,height=3,units="in",res=400, pointsize=9, compression = "lzw")
par(mfrow=c(1,1),mar=c(4,5,1,0),ps=9)
bplot.saps<-barplot(height=oak.means.HA, xaxt="n", las=1, col="gray20",
                    ylab="Saplings (>1 m) per hectare", ylim = c(0,120),
                    density=c(1000,45,0,35),angle=c(45,45,45,135),space=c(0.1,rep(c(0.1,0.5),3),0.1))
abline(h=0, lwd=1.3)
mtext(side=1, line=0.2, cex=1.1,at=bplot.saps, text=c("NF","F"))
mtext(side=1, line=1.4, cex=1.1,at=c(mean(bplot.saps[1:2]),mean(bplot.saps[3:4]),mean(bplot.saps[5:6]),mean(bplot.saps[7:8])), text = c("Control","MR","TH","SW"))
legend("topleft", bty="n",cex=1, inset = c(0.02,0.00),legend = c("QUAL","QUMO","QURU","QUVE"), 
       fill= "gray20",density=c(1000,45,0,35),angle=c(45,45,45,135))

l_ply(seq_along(bplot.saps), function(x) arrows(x0 = bplot.saps[x], y0=as.matrix(oak.means.sums)[x]-as.matrix(oak.SE.vec)[x],x1=bplot.saps[x],
                                                y1=as.matrix(oak.means.sums)[x]+as.matrix(oak.SE.vec)[x], code=3,length=0.03,angle=90,lwd=1))      
dev.off()


## ### ## ### ## ### ## 
####### Stocking #######
  quer_NR$stocked<-NA
  for(i in 1:nrow(quer_NR)){
    if(quer_NR$QU.TotNR[i]>0){
      quer_NR$stocked[i]=1}else{quer_NR$stocked[i]=0}
    }
    quer_NR$stocked
    
  prop.stocked<-aggregate(quer_NR$stocked,by=list(quer_NR$Silvi,quer_NR$Fence), FUN=mean)
    names(prop.stocked)<-c("Silvi","Fence","ProportionStocked")
    
  glm.stock1<-glmer(stocked ~ Silvi + Fence + (1|Site) + (1|Silvi:Site) + (1|Fence:Site), family=binomial,data=quer_NR)
      summary(glm.stock1)
      
      rsquared(glm.stock1)  # marginal = 0.210, conditional = 0.347
      dispersion_glmer(glm.stock1) # 0.998
      
  #glm.stock2<-glmer(stocked ~ Silvi * Fence + (1|Site), family=binomial,data=quer_NR)
      #Once again, including the interaction term crashes the whole thing
  
  cont.mat<-rbind("Fenced vs Unfenced"=c(0,0,0,0,1),
                  "MR vs Control"=c(0,1,0,0,0),
                  "TH vs Control" = c(0,0,1,0,0),
                  "TH+MR vs Control"=c(0,0,0,1,0),
                  "MR vs TH" = c(0,1,-1,0,0),
                  "MR vs MR+TH"=c(0,1,0,-1,0),
                  "TH vs MR+TH"= c(0,0,1,-1,0))
 
  summary(glht(glm.stock1))
  summary(glht(glm.stock1, linfct=cont.mat))  #only MR and TH+MR significantly improved oak stocking
    

  summary(glm.stock1)   #residual deviance = 121.4, residual df = 110
  1 - pchisq(121.4, 110)  #p = 0.215,  model fits well
  qchisq(p=.95,df=110) #critical model deviance threshold = 135.5
  
  str(summary(glm.stock1)) #look at structure of summary statement to pull out coefficients
  
  exp(summary(glm.stock1)$coefficients[,"Estimate"])
  exp(summary(glm.stock1)$coefficients[,"Std. Error"])
  summary(glm.stock1)$coefficients[,"z value"]
  
  cc <- confint(glht(glm.stock1, parm="beta_",method="Wald"))  ## Wald confidence intervals for fixed effects
  
  exp(cc$confint)
  

###############################################
## Repeated measures models for oak saplings ##
    
 saplings.rep<-read.csv("Sapling Table_all years.csv")
  str(saplings.rep)  
    saplings.rep$Year<-as.ordered(saplings.rep$Year)
    saplings.rep$Fence<-as.factor(saplings.rep$Fence)
    
  saplings.rep$ALL.OAKS<-NA  
  for(i in 1:nrow(saplings.rep)){
    
    saplings.rep$ALL.OAKS[i]<-sum(saplings.rep$QUAL[i],saplings.rep$QUMO[i],saplings.rep$QURU[i],saplings.rep$QUVE[i])
    
  }
    
 rm1<- glmer(ALL.OAKS ~ (Silvi + Fence) * Year + (0+Year|PointID)+(1|Site), data=saplings.rep, family=poisson)
      # did not converge, try increasing number of iteration
 rm2<- glmer(ALL.OAKS ~ (Silvi + Fence) * Year + (0+Year|PointID)+(1|Site), data=saplings.rep, family=poisson, glmerControl(optCtrl=list(maxfun=1000000)))
      # still does not converge, try without Fence
 rm3<- glmer(ALL.OAKS ~ Silvi * Year + (0+Year|PointID)+(1|Site), data=saplings.rep, family=poisson, glmerControl(optCtrl=list(maxfun=1000000)))
      #still getting a convergence error, even with any number of optimizers
 rm4<- glmer(ALL.OAKS ~ Silvi * Year + (0+Year|PointID), data=saplings.rep, family=poisson, glmerControl(optCtrl=list(maxfun=1000000)))
      #even pared all the way to bare bones, there just aren't enough oak saplings
 
 plot(saplings.rep$ALL.OAKS~saplings.rep$Year)
 
  sum(saplings.rep$ALL.OAKS[which(saplings.rep$Year!=10)]) #14 total in three previous sampling years
  
  #Allfit####
  #run lines to write Allfit function, then run code under line 139 to use the Allfit Function to assess which optimizer function to use
  library(optimx)
  library(nloptr)
  ###All Fit Code====    
  require("optimx")
  require("nloptr")  
  meth.tab.0 <- cbind(optimizer=
                        rep(c("bobyqa",
                              "Nelder_Mead",
                              "nlminbw",
                              "nmkbw",
                              "optimx",
                              "nloptwrap" ),
                            c(rep(1,5),2)),
                      method= c(rep("",4), "L-BFGS-B",
                                "NLOPT_LN_NELDERMEAD", "NLOPT_LN_BOBYQA"))
  
  nlminbw   <- lme4:::nlminbwrap
  namedList <- lme4:::namedList
  
  if (require("dfoptim")) {
    nmkbw <- function(fn,par,lower,upper,control) {
      if (length(par)==1) {
        res <- optim(fn=fn,par=par,lower=lower,upper=100*par,
                     method="Brent")
      } else {
        if (!is.null(control$maxfun)) {
          control$maxfeval <- control$maxfun
          control$maxfun <- NULL
        }
        res <- nmkb(fn=fn,par=par,lower=lower,upper=upper,control=control)
      }
      res$fval <- res$value
      res
    }
  } else { ## pkg{dfoptim} not available
    ## for nmkb
    meth.tab.0 <- meth.tab.0[meth.tab.0[,"optimizer"] != "nmkbw",]
  }
  
  allFit <- function(m, meth.tab = meth.tab.0,
                     data=NULL,
                     verbose=TRUE,
                     maxfun=1e5)
  {
    stopifnot(length(dm <- dim(meth.tab)) == 2, dm[1] >= 1, dm[2] >= 2,
              is.character(optimizer <- meth.tab[,"optimizer"]),
              is.character(method    <- meth.tab[,"method"]))
    fit.names <- gsub("\\.$","",paste(optimizer, method, sep="."))
    res <- setNames(as.list(fit.names), fit.names)
    for (i in seq_along(fit.names)) {
      if (verbose) cat(fit.names[i],": ")
      ctrl <- list(optimizer=optimizer[i])
      ctrl$optCtrl <- switch(optimizer[i],
                             optimx    = list(method   = method[i]),
                             nloptWrap = list(algorithm= method[i]),
                             list(maxfun=maxfun))
      ctrl <- do.call(if(isGLMM(m)) glmerControl else lmerControl, ctrl)
      tt <- system.time(rr <- tryCatch(update(m, control = ctrl),
                                       error = function(e) e))
      attr(rr, "optCtrl") <- ctrl$optCtrl # contains crucial info here
      attr(rr, "time") <- tt  # store timing info
      res[[i]] <- rr
      if (verbose) cat("[OK]\n")
    }
    
    structure(res, class = "allfit", fit = m, sessionInfo =  sessionInfo(),
              data = data # is dropped if NULL
    )
  }
  
  print.allfit <- function(object, width=80, ...) {
    cat("original model:\n")
    f <- attr(object,"fit")
    ss <- function(x) {
      if (nchar(x)>width) {
        strwrap(paste0(substr(x,1,width-3),"..."))
      } else x
    }
    ff <- ss(deparse(formula(f)))
    cat(ff,"\n")
    cat("data: ",deparse(getCall(f)$data),"\n")
    cat("optimizers (",length(object),"): ",
        ss(paste(names(object),collapse=", ")),"\n",
        sep="")
    which.bad <- sapply(object,is,"error")
    if ((nbad <- sum(which.bad))>0) {
      cat(nbad,"optimizers failed\n")
    }
    cat("differences in negative log-likelihoods:\n")
    nllvec <- -sapply(object[!which.bad],logLik)
    print(summary(nllvec-min(nllvec)))
  }
  
  summary.allfit <- function(object, ...) {
    which.OK <- !sapply(object, is, "error")
    objOK <- object[which.OK]
    msgs <- lapply(objOK, function(x) x@optinfo$conv$lme4$messages)
    fixef <- do.call(rbind, lapply(objOK, fixef))
    llik <- sapply(objOK, logLik)
    times <- t(sapply(objOK, attr, "time"))
    feval <- sapply(objOK, function(x) x@optinfo$feval)
    sdcor <- do.call(rbind, lapply(objOK, function(x)
      as.data.frame(VarCorr(x))[, "sdcor"]))
    theta <- do.call(rbind, lapply(objOK,
                                   function(x) getME(x, "theta")))
    cnm <- lme4:::tnames(objOK[[1]])
    if (sigma(object[[1]])!=1) cnm <- c(cnm,"sigma")
    colnames(sdcor) <- unname(cnm)
    sdcor <- as.data.frame(sdcor)
    namedList(which.OK, msgs, fixef, llik, sdcor, theta, times, feval)
  }
  
  
  #assess which optimizer to use with your specific model====
  aa<-allFit(rm4)
  is.OK <- sapply(aa,is,"merMod") 
  aa.OK <- aa[is.OK]
  lapply(aa.OK,function(x) x@optinfo$conv$lme4$messages) #models with 'NULL' did not have a convergence error
  (lliks <- sort(sapply(aa.OK,logLik))) #make sure the Loglikelthood for your chosen optimizer is not wacky
  