### Natural Regen Seedling Densities ###

require(psych)
require(lme4)
require(multcomp)
require(aod)
require(plyr)
require(MASS)

library(optimx)
library(nloptr)

setwd("~/Library/Mobile Documents/com~apple~CloudDocs/Purdue PC/TNC Oak Project/TNC Forests Submission/Supplementary Materials/Data")

Regen.all<-read.table("Regen Counts Thru Y10.csv", sep=',',header=T)
  head(Regen.all)
  #Counts are summed across four 1 sq. m quadrats at each plot
  
  #drop Year 0 Knapp plots that were never resampled
  Regen<-Regen.all[complete.cases(Regen.all$QUAL),]
  
options(max.print = 15000)  
head(Regen) #5 descriptor columns
  n.fact<-5
ncol(Regen) #57 total columns (52 species)


#Build columns for species groups into regen table####
  ### Group Oaks
  for(i in 1:nrow(Regen)){
    Regen$QUERC_all[i]<-sum(Regen$QUAL[i],Regen$QUCO[i],Regen$QUMO[i],Regen$QURU[i],Regen$QUVE[i])
  }
  Regen$QUERC_all
  
  ### Group Maples
  for(i in 1:nrow(Regen)){
    Regen$ACER_all[i]<-sum(Regen$ACNE[i],Regen$ACRU[i],Regen$ACSA[i])
  }
  Regen$ACER_all
  
  ###Group Hickories
  for(i in 1:nrow(Regen)){
    Regen$CARYA_all[i]<-sum(Regen$CACO[i],Regen$CAGL[i],Regen$CAOV[i],Regen$CATO[i])
  }
  Regen$CARYA_all
  
  ### Group all "DGS" (=desirable group species?)
    #includes white ash, tulip poplar, and black cherry
  for(i in 1:nrow(Regen)){
    Regen$DGS_grp[i]<-sum(Regen$FRAM[i],Regen$LITU[i],Regen$PRSE[i])
                                
  }
  Regen$DGS_grp
  
  ###Group all "UGS" (=undesirable group species?)
  #includes maples and many others
  for(i in 1:nrow(Regen)){
    Regen$UGS_grp[i]<-sum(Regen$ACNE[i],Regen$ACRU[i],Regen$ACSA[i],Regen$CEOC[i],
                                Regen$DIVI[i],Regen$FAGR[i],Regen$GLTR[i],Regen$JUVI[i],
                                Regen$MORU[i],Regen$NYSY[i],Regen$PIVI[i],Regen$PLOC[i],
                                Regen$POGR[i],Regen$SAAL[i],Regen$TIAM[i],Regen$ULAM[i],Regen$ULRU[i])
  }
  Regen$UGS_grp
  
  ###Group all "OWC" (=other woody components?)
  for(i in 1:nrow(Regen)){
    Regen$OWC_grp[i]<-sum(Regen$AMAR[i],Regen$ARSP[i],Regen$ASTR[i],Regen$CACA[i],
                                Regen$CECA[i],Regen$CESC[i],Regen$COFL[i],Regen$ELUM[i],
                                Regen$gooseberry[i],Regen$hawthorn[i],Regen$LIBE[i],Regen$MFR[i],
                                Regen$OSVI[i],Regen$RHCA[i],Regen$RHCO[i],Regen$RHGL[i],
                                Regen$SACA[i],Regen$STTR[i],Regen$vaccinium[i],Regen$VIAC[i],
                                Regen$VIPR[i],Regen$VITIS[i])
    
  }
  Regen$OWC_grp
  
  ###All Regen Column 
  for(i in 1:nrow(Regen)){
    Regen$Regen_ALL[i]<-colSums(t(Regen[,6:57]))[i]
    
  }
  Regen$Regen_ALL
  
#calculate species counts in density per hectare  
  Regen_perHA<-cbind.data.frame(Regen[,1:5],Regen[,6:ncol(Regen)]*2500) 
    head(Regen_perHA)

    
##### values from here on all in stems / ha #
  
## Build tables of means w/ SE ####
Regen_perHA$Fence<-relevel(Regen_perHA$Fence, ref = "NF") #switch reference level to unfenced
  
# Year 0 #
regen.0<-Regen_perHA[which(Regen_perHA$Time==0),] #subset only year 0
    stats.0<-describeBy(regen.0, group=list(regen.0$Fence,regen.0$Silvi), digits = 0,mat=T)
    meanSE.Y0<-stats.0[,c("group1","group2","mean","se")]
    
    mean.Y0.tbl<-data.frame(matrix(vector(), nrow=8, ncol=ncol(Regen)-n.fact),
               stringsAsFactors=F)  #build an empty table
      colnames(mean.Y0.tbl)<-colnames(Regen)[6:ncol(Regen)] #add species names to column headers
      
      for(i in 1:(ncol(Regen)-n.fact)){
        mean.Y0.tbl[1:8,i]<-meanSE.Y0[((n.fact-1+i)*8+1):((n.fact-1+i)*8+8),3]
      }   
       
        rownames(mean.Y0.tbl)<-paste(meanSE.Y0$group2[1:8],meanSE.Y0$group1[1:8],sep="--")
        mean.Y0.tbl  #table of mean densities for each species
      
    se.Y0.tbl<-data.frame(matrix(vector(), nrow=8, ncol=ncol(Regen)-n.fact),
                                stringsAsFactors=F)  #build an empty table for SE
        colnames(se.Y0.tbl)<-colnames(Regen)[6:ncol(Regen)] #add species names to column headers
        
        for(i in 1:(ncol(Regen)-n.fact)){
          se.Y0.tbl[1:8,i]<-meanSE.Y0[((n.fact-1+i)*8+1):((n.fact-1+i)*8+8),4]
        }     #only difference is to pull from SE column (col 4)
        
        rownames(se.Y0.tbl)<-paste(meanSE.Y0$group2[1:8],meanSE.Y0$group1[1:8],sep="--")
        
        se.Y0.tbl  #table of densities SE for each species
     
      #combine into single table for exporting
        meanSE.Y0.tbl<-data.frame(matrix(vector(), nrow=8, ncol=ncol(Regen)-n.fact),
                              stringsAsFactors=F)  #build an empty table
        colnames(meanSE.Y0.tbl)<-colnames(mean.Y0.tbl) #add species names to column headers
        rownames(meanSE.Y0.tbl)<-paste(meanSE.Y0$group2[1:8],meanSE.Y0$group1[1:8],sep="--")
        
        for(i in 1:ncol(mean.Y0.tbl)){
          meanSE.Y0.tbl[,i]<-paste(mean.Y0.tbl[,i]," (",se.Y0.tbl[,i],")", sep="")
        }
        meanSE.Y0.tbl
# Year 2 #     
regen.2<-Regen_perHA[which(Regen_perHA$Time==2),] #subset only year 2
    stats.2<-describeBy(regen.2, group=list(regen.2$Fence,regen.2$Silvi), digits = 0,mat=T)
    meanSE.Y2<-stats.2[,c("group1","group2","mean","se")]
    
    mean.Y2.tbl<-data.frame(matrix(vector(), nrow=8, ncol=ncol(Regen)-n.fact),
                            stringsAsFactors=F)  #build an empty table
    colnames(mean.Y2.tbl)<-colnames(Regen)[6:ncol(Regen)] #add species names to column headers
    
    for(i in 1:(ncol(Regen)-n.fact)){
      mean.Y2.tbl[1:8,i]<-meanSE.Y2[((n.fact-1+i)*8+1):((n.fact-1+i)*8+8),3]
    }   
    
    rownames(mean.Y2.tbl)<-paste(meanSE.Y2$group2[1:8],meanSE.Y2$group1[1:8],sep="--")
    mean.Y2.tbl  #table of mean densities for each species
    
    se.Y2.tbl<-data.frame(matrix(vector(), nrow=8, ncol=ncol(Regen)-n.fact),
                          stringsAsFactors=F)  #build an empty table for SE
    colnames(se.Y2.tbl)<-colnames(Regen)[6:ncol(Regen)] #add species names to column headers
    
    for(i in 1:(ncol(Regen)-n.fact)){
      se.Y2.tbl[1:8,i]<-meanSE.Y2[((n.fact-1+i)*8+1):((n.fact-1+i)*8+8),4]
    }     #only difference is to pull from SE column (col 4)
    
    rownames(se.Y2.tbl)<-paste(meanSE.Y2$group2[1:8],meanSE.Y2$group1[1:8],sep="--")
    
    se.Y2.tbl  #table of densities SE for each species
    
    #combine into single table
    meanSE.Y2.tbl<-data.frame(matrix(vector(), nrow=8, ncol=ncol(Regen)-n.fact),
                              stringsAsFactors=F)  #build an empty table
    colnames(meanSE.Y2.tbl)<-colnames(mean.Y2.tbl) #add species names to column headers
    rownames(meanSE.Y2.tbl)<-paste(meanSE.Y2$group2[1:8],meanSE.Y2$group1[1:8],sep="--")
    
    for(i in 1:ncol(mean.Y2.tbl)){
      meanSE.Y2.tbl[,i]<-paste(mean.Y2.tbl[,i]," (",se.Y2.tbl[,i],")", sep="")
    }
    meanSE.Y2.tbl
    
# Year 4 #
regen.4<-Regen_perHA[which(Regen_perHA$Time==4),] #subset only year 4
    stats.4<-describeBy(regen.4, group=list(regen.4$Fence,regen.4$Silvi), digits=0,mat=T)
    meanSE.Y4<-stats.4[,c("group1","group2","mean","se")]
    
    mean.Y4.tbl<-data.frame(matrix(vector(), nrow=8, ncol=ncol(Regen)-n.fact),
                            stringsAsFactors=F)  #build an empty table
    colnames(mean.Y4.tbl)<-colnames(Regen)[6:ncol(Regen)] #add species names to column headers
    
    for(i in 1:(ncol(Regen)-n.fact)){
      mean.Y4.tbl[1:8,i]<-meanSE.Y4[((n.fact-1+i)*8+1):((n.fact-1+i)*8+8),3]
    }   
    
    rownames(mean.Y4.tbl)<-paste(meanSE.Y4$group2[1:8],meanSE.Y4$group1[1:8],sep="--")
    mean.Y4.tbl  #table of mean densities for each species
    
    se.Y4.tbl<-data.frame(matrix(vector(), nrow=8, ncol=ncol(Regen)-n.fact),
                          stringsAsFactors=F)  #build an empty table for SE
    colnames(se.Y4.tbl)<-colnames(Regen)[6:ncol(Regen)] #add species names to column headers
    
    for(i in 1:(ncol(Regen)-n.fact)){
      se.Y4.tbl[1:8,i]<-meanSE.Y4[((n.fact-1+i)*8+1):((n.fact-1+i)*8+8),4]
    }     #only difference is to pull from SE column (col 4)
    
    rownames(se.Y4.tbl)<-paste(meanSE.Y4$group2[1:8],meanSE.Y4$group1[1:8],sep="--")
    
    se.Y4.tbl  #table of densities SE for each species
    
    #combine into single table
    meanSE.Y4.tbl<-data.frame(matrix(vector(), nrow=8, ncol=ncol(Regen)-n.fact),
                              stringsAsFactors=F)  #build an empty table
    colnames(meanSE.Y4.tbl)<-colnames(mean.Y4.tbl) #add species names to column headers
    rownames(meanSE.Y4.tbl)<-paste(meanSE.Y4$group2[1:8],meanSE.Y4$group1[1:8],sep="--")
    
    for(i in 1:ncol(mean.Y4.tbl)){
      meanSE.Y4.tbl[,i]<-paste(mean.Y4.tbl[,i]," (",se.Y4.tbl[,i],")", sep="")
    }
    meanSE.Y4.tbl

# Year 10 #
regen.10<-Regen_perHA[which(Regen_perHA$Time==10),] #subset only year 10
    stats.10<-describeBy(regen.10, group=list(regen.10$Fence,regen.10$Silvi), digits=0,mat=T)
    meanSE.Y10<-stats.10[,c("group1","group2","mean","se")]
    
    mean.Y10.tbl<-data.frame(matrix(vector(), nrow=8, ncol=ncol(Regen)-n.fact),
                            stringsAsFactors=F)  #build an empty table
    colnames(mean.Y10.tbl)<-colnames(Regen)[6:ncol(Regen)] #add species names to column headers
    
    for(i in 1:(ncol(Regen)-n.fact)){
      mean.Y10.tbl[1:8,i]<-meanSE.Y10[((n.fact-1+i)*8+1):((n.fact-1+i)*8+8),3]
    }   
    
    rownames(mean.Y10.tbl)<-paste(meanSE.Y10$group2[1:8],meanSE.Y10$group1[1:8],sep="--")
    mean.Y10.tbl  #table of mean densities for each species
    
    se.Y10.tbl<-data.frame(matrix(vector(), nrow=8, ncol=ncol(Regen)-n.fact),
                          stringsAsFactors=F)  #build an empty table for SE
    colnames(se.Y10.tbl)<-colnames(Regen)[6:ncol(Regen)] #add species names to column headers
    
    for(i in 1:(ncol(Regen)-n.fact)){
      se.Y10.tbl[1:8,i]<-meanSE.Y10[((n.fact-1+i)*8+1):((n.fact-1+i)*8+8),4]
    }     #only difference is to pull from SE column (col 4)
    
    rownames(se.Y10.tbl)<-paste(meanSE.Y10$group2[1:8],meanSE.Y10$group1[1:8],sep="--")
    
    se.Y10.tbl  #table of densities SE for each species
    
    #combine into single table
    meanSE.Y10.tbl<-data.frame(matrix(vector(), nrow=8, ncol=ncol(Regen)-n.fact),
                              stringsAsFactors=F)  #build an empty table
    colnames(meanSE.Y10.tbl)<-colnames(mean.Y10.tbl) #add species names to column headers
    rownames(meanSE.Y10.tbl)<-paste(meanSE.Y10$group2[1:8],meanSE.Y10$group1[1:8],sep="--")
    
    for(i in 1:ncol(mean.Y10.tbl)){
      meanSE.Y10.tbl[,i]<-paste(mean.Y10.tbl[,i]," (",se.Y10.tbl[,i],")", sep="")
    }
    meanSE.Y10.tbl
  
#a double check on calculations
Regen_perHA$Fence<-relevel(Regen_perHA$Fence, ref = "NF")
aggregate(Regen_perHA$Regen_ALL[which(Regen_perHA$Time==4)], by = list(Regen_perHA$Fence[which(Regen_perHA$Time==4)], Regen_perHA$Silvi[which(Regen_perHA$Time==4)]), FUN=mean)

# MEANS OF EACH SPECIES IN EACH YEAR####
  means.tbl<-rbind.data.frame(mean.Y0.tbl,mean.Y2.tbl,mean.Y4.tbl
                   ,mean.Y10.tbl
                   )
# SE of each species in each year 
  SE.tbl<-rbind.data.frame(se.Y0.tbl,se.Y2.tbl,se.Y4.tbl
                              ,se.Y10.tbl
  )
  
#Barplot for Forests manuscript  
  setwd("~/Library/Mobile Documents/com~apple~CloudDocs/Purdue PC/TNC Oak Project/TNC Forests Submission/Forests Figs")  
  tiff(filename="Forests Fig. 4_Oak Seedlings.tiff",width=6.5,height=3,units="in",res=400, pointsize=8,
       compression = "lzw")  
  par(mar=c(5,6,4,1)+0.1,ps=9)
  meanstable.2<-rbind.data.frame(means.tbl[c(1:2, 9:10,17:18,25:26,
                                                   3:4,11:12,19:20,27:28,
                                                   5:6,13:14,21:22,29:30,
                                                   7:8,15:16,23:24,31:32),])
  
  SEtable.2<-rbind.data.frame(SE.tbl[c(1:2, 9:10,17:18,25:26,
                                             3:4,11:12,19:20,27:28,
                                             5:6,13:14,21:22,29:30,
                                             7:8,15:16,23:24,31:32),])
  bplot.oaks4<-barplot(height=meanstable.2$QUERC_all, las=1, yaxt="n",
                       space = c(rep(c(0.3,0.1),4),rep(c(2,rep(c(0.1,0.3),3),0.1),3)),
                       ylim=c(0,25000), 
                       col=c("gray30"), density=c(1000,45), angle=45)
  axis(2, at=seq(0,25000,5000), labels=c("0","5,000","10,000","15,000","20,000","25,000"),las=1)
  abline(h=0)
  
  mtext(side=2, line = 4.5, text="Seedlings per hectare", cex=1)
  mtext(side=1, text = c("Year:",rep(c("0","2","4", "10"),4)), line = 0.8, at=c(-2.4,bplot.oaks4[c(1,3,5,7,9,11,13,15,17,19,21,23,25,27,29,31)]+0.55))
  mtext(side=1, text = c("Control","Midstory Removal","Crown Thinning","Shelterwood"), line =2, 
        at=c(mean(bplot.oaks4[1:8]),mean(bplot.oaks4[9:16]),mean(bplot.oaks4[17:24]),mean(bplot.oaks4[25:32])))
  #mtext(side=1, line= 0.8,text = c("Fence:",rep(c("NF","F"),16)), at=c(-2.7,bplot.oaks))
  legend("topright",legend=c("Unfenced","Fenced"), 
         #col = c("gray10","gray20","gray35","gray55","gray80")
         fill="gray20", density=c(1000,45),angle=45, bty="n")
  l_ply(seq_along(bplot.oaks4), function(x) arrows(x0 = bplot.oaks4[x], y0=meanstable.2$QUERC_all[x],x1=bplot.oaks4[x],
                                                   y1=meanstable.2$QUERC_all[x]+SEtable.2$QUERC_all[x], code=2,length=0.05,angle=90,lwd=1))
  #mtext(text="Oaks",side=3,line=2,cex=2,adj=0)
  dev.off()  
  
  
  
Regen_perHA<-Regen_perHA[complete.cases(Regen_perHA$QUAL),] 
Regen<-Regen[complete.cases(Regen$QUAL),] 
      Regen$Fence<-factor(Regen$Fence, levels(Regen$Fence)[c(2,1)]) #set NoFence as reference level
      levels(Regen$Fence)  #check that NF is listed first
      str(Regen)
  #Oak poisson model
library(blmeco) #for dispersion for mixed models
library(piecewiseSEM) #To caculate R2 for mixed models
      
  lm.Y2.oak.pois<-glmer(Regen$QUERC_all[which(Regen$Time==2)]~Regen$Silvi[which(Regen$Time==2)]*Regen$Fence[which(Regen$Time==2)]+(1|Regen$Site[which(Regen$Time==2)]), family = "poisson")
      plot(lm.Y2.oak.pois)
      
      lm.Y2.oak.pois_add<-update(lm.Y2.oak.pois, ~Regen$Silvi[which(Regen$Time==2)]+Regen$Fence[which(Regen$Time==2)]+(1|Regen$Site[which(Regen$Time==2)]))
          anova(lm.Y2.oak.pois, lm.Y2.oak.pois_add) #drop interaction
        
        plot(lm.Y2.oak.pois_add)
        hist(residuals(lm.Y2.oak.pois_add))
        dispersion_glmer(lm.Y2.oak.pois_add) #1.30
      
      summary(lm.Y2.oak.pois_add) #no signficant differences
      
      lm.Y2.oak.pois_null<-update(lm.Y2.oak.pois, ~1+(1|Regen$Site[which(Regen$Time==2)]))
          anova(lm.Y2.oak.pois_add,lm.Y2.oak.pois_null)
      lm.Y2.oak.pois_fnc<-update(lm.Y2.oak.pois, ~Regen$Fence[which(Regen$Time==2)]+(1|Regen$Site[which(Regen$Time==2)]))
          anova(lm.Y2.oak.pois_fnc,lm.Y2.oak.pois_null)
      lm.Y2.oak.pois_silv<-update(lm.Y2.oak.pois, ~Regen$Silvi[which(Regen$Time==2)]+(1|Regen$Site[which(Regen$Time==2)]))
          anova(lm.Y2.oak.pois_silv,lm.Y2.oak.pois_null)
        
        rsquared(lm.Y2.oak.pois_null)
        rsquared(lm.Y2.oak.pois_add)
        
  lm.Y4.oak.pois<-glmer(Regen$QUERC_all[which(Regen$Time==4)]~Regen$Silvi[which(Regen$Time==4)]*Regen$Fence[which(Regen$Time==4)]+(1|Regen$Site[which(Regen$Time==4)]), family = "poisson")
  lm.Y4.oak.pois_add<-update(lm.Y4.oak.pois, ~Regen$Silvi[which(Regen$Time==4)]+Regen$Fence[which(Regen$Time==4)]+(1|Regen$Site[which(Regen$Time==4)]))
    anova(lm.Y4.oak.pois, lm.Y4.oak.pois_add) #drop interaction
  
   plot(lm.Y4.oak.pois_add)
      hist(residuals(lm.Y4.oak.pois_add))
      dispersion_glmer(lm.Y4.oak.pois_add)
      
      
      
      overdisp_fun <- function(model) {
        ## number of variance parameters in an n-by-n variance-covariance matrix
        vpars <- function(m) {
          nrow(m) * (nrow(m) + 1)/2
        }
        model.df <- sum(sapply(VarCorr(model), vpars)) + length(fixef(model))
        rdf <- nrow(model.frame(model)) - model.df
        rp <- residuals(model, type = "pearson")
        Pearson.chisq <- sum(rp^2)
        prat <- Pearson.chisq/rdf
        pval <- pchisq(Pearson.chisq, df = rdf, lower.tail = FALSE)
        c(chisq = Pearson.chisq, ratio = prat, rdf = rdf, p = pval)
      } #Ben Bolker's overdispersion function (http://glmm.wikidot.com/faq)
      
      overdisp_fun(lm.Y4.oak.pois_add) #not an issue in the oak model
      
      wald.test(b=fixef(lm.Y4.oak.pois), Sigma=vcov(lm.Y4.oak.pois),Terms=c(2:4,6:8)) #test Silvi effect; p=0.14
      wald.test(b=fixef(lm.Y4.oak.pois), Sigma=vcov(lm.Y4.oak.pois),Terms=5:8) #test Fence effect; p = 0.14
      wald.test(b=fixef(lm.Y4.oak.pois), Sigma=vcov(lm.Y4.oak.pois),Terms=6:8) #test interaction; p = 0.67
      
      summary(lm.Y4.oak.pois_add) #
      anova(lm.Y4.oak.pois)
      
      
  lm.Y10.oak.pois<-        glmer(Regen$QUERC_all[which(Regen$Time==10)]~Regen$Silvi[which(Regen$Time==10)]*Regen$Fence[which(Regen$Time==10)]+(1|Regen$Site[which(Regen$Time==10)]), family = "poisson",data=Regen) 
      plot(lm.Y10.oak.pois)
      
      lm.Y10.oak.pois_add<-glmer(Regen$QUERC_all[which(Regen$Time==10)]~Regen$Silvi[which(Regen$Time==10)]+Regen$Fence[which(Regen$Time==10)]+(1|Regen$Site[which(Regen$Time==10)]), family = "poisson",data=Regen) 
        anova(lm.Y10.oak.pois,lm.Y10.oak.pois_add) #drop interaction 
      
      
      
      dispersion_glmer(lm.Y10.oak.pois_add)
      summary(lm.Y10.oak.pois_add)

      #test model g.o.f. using residual deviance (~ chi sq)
      1-pchisq(135.3,49) #model fit is poor; significant residual deviance
      
      rsquared(lm.Y10.oak.pois_add) #random site intercept term accounts for nearly 30% of the variance, and fixed effects only account for 8%

      lm.Y10.oak.pois2<-glmer(Regen$QUERC_all[which(Regen$Time==10)]~Regen$Silvi[which(Regen$Time==10)] + Regen$Fence[which(Regen$Time==10)]+(1|Regen$Site[which(Regen$Time==10)]), family = "poisson",data=Regen) 
          anova(lm.Y10.oak.pois,lm.Y10.oak.pois2)
      
          dispersion_glmer(lm.Y10.oak.pois2)
          rsquared(lm.Y10.oak.pois2)
          summary(lm.Y10.oak.pois2)
            1-pchisq(135.3,49)
            
            
# repeated measures poisson
      Regen$Fence<-relevel(Regen$Fence, ref="NF")
      Regen$Time[which(Regen$Time==1)]<-2 #for simplicity
      Regen$PlotUnique<-paste(Regen$Site,"-",Regen$Plot)
      rm.oak.pois<-glmer(QUERC_all~(Silvi+Fence)*Time+(1|Site)+(1+Time|PlotUnique), family = "poisson",data=Regen) 
            #does not converge, use Allfit code at bottom of this script
            #nlminbw optimizer should help
      
      rm.oak.pois2<-glmer(QUERC_all~(Silvi+Fence)*Time+(1|Site)+(1+Time|PlotUnique), family = "poisson",data=Regen, glmerControl(optimizer = "nlminbw")) 
          #should interaction be included?
          rm.oak.pois3<-update(rm.oak.pois2,~(Silvi*Fence*Time)+(1|Site)+(1+Time|PlotUnique))
            anova(rm.oak.pois3,rm.oak.pois2) #interactions do not improve model
          
          rsquared(rm.oak.pois2) 
          dispersion_glmer(rm.oak.pois2) #good
          
          summary(rm.oak.pois2)
          
          1-pchisq(691.2,225)
          rsquared(rm.oak.pois2)
          
          cont.mat1<-rbind("Silvi:Time vs Control:Time" =  c(0,0,0,0,0,0,1/3,1/3,1/3,0),
                           "Fence:Time vs Unfenced:Time" = c(0,0,0,0,0,0,0  ,0  ,0  ,1))
          summary(glht(rm.oak.pois2, linfct=cont.mat1))
          
 
#Allfit####
        #run lines to write Allfit function, then run code under line 139 to use the Allfit Function to assess which optimizer function to use
        library(optimx)
        library(nloptr)
        ###All Fit Code====    
        require("optimx")
        require("nloptr")  
        meth.tab.0 <- cbind(optimizer=
                              rep(c("bobyqa",
                                    "Nelder_Mead",
                                    "nlminbw",
                                    "nmkbw",
                                    "optimx",
                                    "nloptwrap" ),
                                  c(rep(1,5),2)),
                            method= c(rep("",4), "L-BFGS-B",
                                      "NLOPT_LN_NELDERMEAD", "NLOPT_LN_BOBYQA"))
        
        nlminbw   <- lme4:::nlminbwrap
        namedList <- lme4:::namedList
        
        if (require("dfoptim")) {
          nmkbw <- function(fn,par,lower,upper,control) {
            if (length(par)==1) {
              res <- optim(fn=fn,par=par,lower=lower,upper=100*par,
                           method="Brent")
            } else {
              if (!is.null(control$maxfun)) {
                control$maxfeval <- control$maxfun
                control$maxfun <- NULL
              }
              res <- nmkb(fn=fn,par=par,lower=lower,upper=upper,control=control)
            }
            res$fval <- res$value
            res
          }
        } else { ## pkg{dfoptim} not available
          ## for nmkb
          meth.tab.0 <- meth.tab.0[meth.tab.0[,"optimizer"] != "nmkbw",]
        }
        
        allFit <- function(m, meth.tab = meth.tab.0,
                           data=NULL,
                           verbose=TRUE,
                           maxfun=1e5)
        {
          stopifnot(length(dm <- dim(meth.tab)) == 2, dm[1] >= 1, dm[2] >= 2,
                    is.character(optimizer <- meth.tab[,"optimizer"]),
                    is.character(method    <- meth.tab[,"method"]))
          fit.names <- gsub("\\.$","",paste(optimizer, method, sep="."))
          res <- setNames(as.list(fit.names), fit.names)
          for (i in seq_along(fit.names)) {
            if (verbose) cat(fit.names[i],": ")
            ctrl <- list(optimizer=optimizer[i])
            ctrl$optCtrl <- switch(optimizer[i],
                                   optimx    = list(method   = method[i]),
                                   nloptWrap = list(algorithm= method[i]),
                                   list(maxfun=maxfun))
            ctrl <- do.call(if(isGLMM(m)) glmerControl else lmerControl, ctrl)
            tt <- system.time(rr <- tryCatch(update(m, control = ctrl),
                                             error = function(e) e))
            attr(rr, "optCtrl") <- ctrl$optCtrl # contains crucial info here
            attr(rr, "time") <- tt  # store timing info
            res[[i]] <- rr
            if (verbose) cat("[OK]\n")
          }
          
          structure(res, class = "allfit", fit = m, sessionInfo =  sessionInfo(),
                    data = data # is dropped if NULL
          )
        }
        
        print.allfit <- function(object, width=80, ...) {
          cat("original model:\n")
          f <- attr(object,"fit")
          ss <- function(x) {
            if (nchar(x)>width) {
              strwrap(paste0(substr(x,1,width-3),"..."))
            } else x
          }
          ff <- ss(deparse(formula(f)))
          cat(ff,"\n")
          cat("data: ",deparse(getCall(f)$data),"\n")
          cat("optimizers (",length(object),"): ",
              ss(paste(names(object),collapse=", ")),"\n",
              sep="")
          which.bad <- sapply(object,is,"error")
          if ((nbad <- sum(which.bad))>0) {
            cat(nbad,"optimizers failed\n")
          }
          cat("differences in negative log-likelihoods:\n")
          nllvec <- -sapply(object[!which.bad],logLik)
          print(summary(nllvec-min(nllvec)))
        }
        
        summary.allfit <- function(object, ...) {
          which.OK <- !sapply(object, is, "error")
          objOK <- object[which.OK]
          msgs <- lapply(objOK, function(x) x@optinfo$conv$lme4$messages)
          fixef <- do.call(rbind, lapply(objOK, fixef))
          llik <- sapply(objOK, logLik)
          times <- t(sapply(objOK, attr, "time"))
          feval <- sapply(objOK, function(x) x@optinfo$feval)
          sdcor <- do.call(rbind, lapply(objOK, function(x)
            as.data.frame(VarCorr(x))[, "sdcor"]))
          theta <- do.call(rbind, lapply(objOK,
                                         function(x) getME(x, "theta")))
          cnm <- lme4:::tnames(objOK[[1]])
          if (sigma(object[[1]])!=1) cnm <- c(cnm,"sigma")
          colnames(sdcor) <- unname(cnm)
          sdcor <- as.data.frame(sdcor)
          namedList(which.OK, msgs, fixef, llik, sdcor, theta, times, feval)
        }
        
        
        #assess which optimizer to use with your specific model====
        aa<-allFit(rm.comp1)
        is.OK <- sapply(aa,is,"merMod") 
        aa.OK <- aa[is.OK]
        lapply(aa.OK,function(x) x@optinfo$conv$lme4$messages) #models with 'NULL' did not have a convergence error
        (lliks <- sort(sapply(aa.OK,logLik))) #make sure the Loglikelthood for your chosen optimizer is not wacky
        