## R Code for Frank, Rathfon, and Saunders 2018 ##
### Analysis of overstory data ###

library(lme4)
library(lmerTest)
library(multcomp)
library(psych) 

setwd("~/Library/Mobile Documents/com~apple~CloudDocs/Purdue PC/TNC Oak Project/TNC Forests Submission/Supplementary Materials")
## Overstory basal area ##
options(max.print = 10000)
BA_07_11<-read.csv("Basal Area.csv")
  head(BA_07_11)
  BA_07_11$Init.Change  =  (BA_07_11$BA2009ave-BA_07_11$BA2007)/BA_07_11$BA2007
    
    attach(BA_07_11)
    summary(lmer(BA2007~Silvi-1+(1|Site))) #to obtain means with accurate SE
      anova(lmer(BA2007~Silvi+(1|Site)))  #p = 0.66
    summary(lmer(BA2009ave~Silvi-1+(1|Site)))$coefficients[,1:2] 
      #anova(lmer(BA2009ave~Silvi+(1|Site))) #p = 0.04
      #summary(glht(lmer(BA2009ave~Silvi-1+(1|Site)), linfct=mcp(Silvi="Tukey")))
    summary(lmer(BA2010_11~Silvi-1+(1|Site)))$coefficients[,1:2] 
      #anova(lmer(BA2010_11~Silvi+(1|Site))) #p = 0.03
      #summary(glht(lmer(BA2010_11~Silvi-1+(1|Site)), linfct=mcp(Silvi="Tukey")))
      
  #basal area at each site
    summary(lm(BA2007~Site-1))
    
    #BA for each silvicultural treatment at each site
      summary(lm(BA2007~Silvi:Site-1))
      summary(lm(BA2009ave~Silvi:Site-1))
    

    dBA.lm<-lmer((Init.Change)~Silvi-1+(1|Site))
      summary(dBA.lm)$coefficients[,1:2]
      summary(glht(dBA.lm, linfct=mcp(Silvi="Tukey")))
      
    detach(BA_07_11)

OS_07<-read.csv("Overstory DBH 2007.csv")      
  head(OS_07)
  OS_07$DBH.cm<-round(OS_07$DBH*2.54,1)
  
  par(mfrow=c(1,4),mar=c(3,4,4,1)+0.1, oma=c(2,2,0,0)) 
  hist(OS_07$DBH.cm[which(OS_07$Trt_assignment=="Control")],breaks=10,xlim=c(0,160),ylim=c(0,140),xlab=NULL, ylab=NULL, main=NULL) #control
    #text(100,120,labels=expression("mean BA = 23.9 m"^2*" ha"^-1), cex=1.3)
    mtext(side=3,line=1,adj=0,"Control", cex=1.5)
  hist(OS_07$DBH.cm[which(OS_07$Trt_assignment=="Midstory")],breaks=10,xlim=c(0,160),ylim=c(0,140),xlab=NULL, ylab=NULL, main=NULL) #control
    #text(100,120,labels=expression("mean BA = 23.9 m"^2*" ha"^-1), cex=1.3)
    mtext(side=3,line=1,adj=0,"Midstory Removal", cex=1.5)
    
##Pretreatment oak stocking
    Site.DBH<-aggregate((pi*(OS_07$DBH/24)^2)*10, by = list(OS_07$Site, OS_07$PointID), FUN=sum)
    Site.oak<-aggregate((pi*(OS_07$DBH[which(grepl("QU",OS_07$Species))]/24)^2)*10, by = list(OS_07$Site[which(grepl("QU",OS_07$Species))], OS_07$PointID[which(grepl("QU",OS_07$Species))]), FUN=sum)
    Site.merge<-merge.data.frame(Site.DBH,Site.oak, by=c("Group.1","Group.2"),all.x=T)
        names(Site.merge)=c("Site","PointID","TotalBAFt","OakBAFt")
        Site.merge$OakBAFt[which(is.na(Site.merge$OakBAFt))]<-0
        Site.merge$Oak.Stock<-Site.merge$OakBAFt/Site.merge$TotalBAFt
        aggregate(Site.merge$Oak.Stock~Site.merge$Site,FUN=mean) #proportion BA as oak per site
        

#tiff(filename="Overstory Size Class Distributions_2007.tiff",width=11,height=3,units="in",res=400, pointsize=8,compression = "lzw")
    par(mfrow=c(1,4),mar=c(3,4,4,1)+0.1, oma=c(2,2,0,0)) 
    hist(OS_07$DBH.cm[which(OS_07$Trt_assignment=="Control")],col="dodgerblue3",las=1,breaks=c(5.1,seq(10,160,10)),xlim=c(0,160),ylim=c(0,0.12),xlab=NULL, ylab=NULL, main=NULL,freq=F, cex.axis=1.5) #control
      #text(100,0.10,labels=expression("mean BA = 23.9 m"^2*" ha"^-1), cex=1.3)
      mtext(side=3,line=1,adj=0,"Control")
    hist(OS_07$DBH.cm[which(OS_07$Trt_assignment=="Midstory")],col="dodgerblue3",las=1,breaks=c(5.1,seq(10,160,10)),xlim=c(0,160),ylim=c(0,0.12),xlab=NULL, ylab=NULL, main=NULL,freq=F, cex.axis=1.5) #midstory removal
      #text(100,0.10,labels=expression("mean BA = 20.8 m"^2*" ha"^-1), cex=1.3)
      mtext(side=3,line=1,adj=0,"Midstory Removal")
    hist(OS_07$DBH.cm[which(OS_07$Trt_assignment=="Thinning")],col="dodgerblue3",las=1,breaks=c(5.1,seq(10,160,10)),xlim=c(0,160),ylim=c(0,0.12),xlab=NULL, ylab=NULL, main=NULL,freq=F, cex.axis=1.5) #thinning
      #text(100,0.10,labels=expression("mean BA = 19.3 m"^2*" ha"^-1), cex=1.3)
      mtext(side=3,line=1,adj=0,"Thinning")
    hist(OS_07$DBH.cm[which(OS_07$Trt_assignment=="Shelterwood")],col="dodgerblue3",las=1,breaks=c(5.1,seq(10,160,10)),xlim=c(0,160),ylim=c(0,0.12),xlab=NULL, ylab=NULL, main=NULL,freq=F, cex.axis=1.5) #shelterwood
      #text(100,0.10,labels=expression("mean BA = 17.9 m"^2*" ha"^-1), cex=1.3)  
      mtext(side=3,line=1,adj=0,"Shelterwood")
    mtext(side=1,outer=T,line=0,"Diameter (cm)",cex=1.3)
    mtext(side=2,outer=T,line=0,"Density", cex=1.3)
    #dev.off()
    
OS_Fix<-read.csv("Overstory Fixed Radius 2018.csv")[,1:4]
  head(OS_Fix)
  OS_17<-merge(OS_07[c("Site","PointID","Trt_assignment")], OS_Fix, by=c("Site","PointID"))
  OS_17$DBH.cm<-as.numeric(OS_17$DBH.cm)
      OS_17<-OS_17[which(OS_17$DBH.cm>5.0),]
  
  BA.FUN<- function(dbh.cm){
    pi*(dbh.cm/2)^2
  }
  
  OS_Fix$BA_cm2<-sapply(OS_Fix$DBH.cm, FUN=BA.FUN)  #per 1/10 acre
    OS_Fix$BA_m2<-OS_Fix$BA_cm2*0.0001              #per 1/10 acre
      OS_Fix$BA_m2_ha<-OS_Fix$BA_m2*10/0.404686     #per hectare
      
  OS.fix.sum<-with(OS_Fix,expand.grid(unique(PointID), unique(Site)))
    names(OS.fix.sum)=c("PointID","Site")
    OS.fix.sum<-OS.fix.sum[order(OS.fix.sum$Site,OS.fix.sum$PointID),]   
    OS.fix.sum<-OS.fix.sum[ !(OS.fix.sum$Site %in% "Knapp" & OS.fix.sum$PointID %in% c(111,112,121,122,211,212)), ] #treatments never went in at these "plots"

  OS.fix.sum$BA_m2_ha<-aggregate(OS_Fix$BA_m2_ha, by=list(OS_Fix$PointID, OS_Fix$Site), FUN=sum)$x
  
OS_10BAF<-read.csv("Overstory Prism Table.csv")
  OS_10BAF$sum<-NA
    for(i in 1:nrow(OS_10BAF)){
      OS_10BAF$sum[i]<-sum(OS_10BAF[i,5:18])
    }
  OS_10BAF$BA_ft2_ac<-OS_10BAF$sum*10
  OS_10BAF$BA_m2_ha<-OS_10BAF$BA_ft2_ac/0.404686*0.092903
  
  OS.fix.sum$Silvi=BA_07_11$Silvi
  OS_all<-rbind.data.frame(OS_10BAF[c("Site","Silvi","PointID","BA_m2_ha")],
                           OS.fix.sum[c("Site","Silvi","PointID","BA_m2_ha")])
  
    summary(lmer(OS_all$BA_m2_ha~OS_all$Silvi-1+(1|OS_all$Site)))$coefficients[,1:2] 
  
    #at each site
    summary(lm(OS_all$BA_m2_ha~OS_all$Silvi:OS_all$Site-1))
    
        
OS_all$Fence<-as.factor(OS_10BAF$Fence)
OS_all$Silvi<-OS_10BAF$Silvi
  str(OS_all)
          
OS_stats.m<-describeBy(OS_all$BA_m2_ha, group = OS_all$Silvi, mat=T)
      barplot(OS_stats.m$mean)

detach(BA_07_11)            
attach(OS_all)
      
  lmm.BA<-lmer(BA_m2_ha~Silvi + (1|Site))
      plot(lmm.BA)
      hist(residuals(lmm.BA))  #right skew
      
    lmm.BA.rs<-lmer(BA_m2_ha~Silvi + (1+Silvi|Site))
        plot(lmm.BA.rs) #improves residuals a bit
        hist(residuals(lmm.BA.rs)) #still skewed
        
      anova(lmm.BA.rs,lmm.BA) #do not include random slope
      
  lmm.BA.sqrt<-lmer(sqrt(BA_m2_ha+0.5)~Silvi+(1|Site))
      plot(lmm.BA.sqrt) #much improved
      hist(residuals(lmm.BA.sqrt),breaks = 10) #quite nice
      
    summary(lmm.BA.sqrt)    
    summary(glht(lmm.BA.sqrt, mcp(Silvi="Tukey")))  #penalty makes only THMR vs Control comparison significant
    
    
OS_Fix<-merge(OS_all[c("Site","PointID","Fence","Silvi")], OS_Fix, by=c("Site","PointID"))  
  head(OS_Fix)
  
  hist.c<-hist(OS_Fix$DBH.cm[which(OS_Fix$Silvi=="C")],plot=F,breaks=c(5,seq(20,160,by=10)))
  sum(hist.c$dens) 
  sum(diff(hist.c$breaks)*hist.c$density)
    hist(OS_Fix$DBH.cm[which(OS_Fix$Silvi=="C")],plot=F,breaks=c(5,seq(20,160,by=10)))
  
      
OS_Fix<-OS_Fix[which(OS_Fix$DBH.cm>5),]
  OS_Fix$DBH.inch<-OS_Fix$DBH.cm/2.54
      
#tiff(filename="Forests Fig. 1_Overstory Size Class.tiff",width=6,height=5,units="in",res=400, pointsize=9, compression = "lzw")
  OS_Fix$DBH.cm[which(OS_Fix$DBH.cm>85)] = 84.9 #hacky way to make a >85cm bin
    par(mfrow=c(2,2),mar=c(3,4,4,1)+0.1, oma=c(2,2,0,0),ps=9) 
    hist(OS_Fix$DBH.cm[which(OS_Fix$Silvi=="C")],freq=F,axes=F,las=1,breaks=c(5,seq(15,85,by=10)),xlim=c(0,85),ylim=c(0,0.10),xlab=NULL, ylab=NULL, main=NULL, col="gray50") #control
      #text(100,120,labels=expression("mean BA = 23.9 m"^2*" ha"^-1), cex=1.3)
      text(x=5,y=0.095,adj=0,"Control")
        axis(side=1,at=seq(5,85,by=10), labels=c("5","15","25","35","45","55","65","75","85+"))
        axis(side=2,line=-0.5,at=seq(0,0.10,by=0.02),las=1)
    hist(OS_Fix$DBH.cm[which(OS_Fix$Silvi=="MR")],freq=F,axes=F,las=1,breaks=c(5,seq(15,85,by=10)),xlim=c(0,85),ylim=c(0,0.1),xlab=NULL, ylab=NULL, main=NULL, col="gray50") #midstory removal
      #text(100,120,labels=expression("mean BA = 20.8 m"^2*" ha"^-1), cex=1.3)
      text(x=5,y=0.095,adj=0,"Midstory Removal")
        axis(side=1,at=seq(5,85,by=10), labels=c("5","15","25","35","45","55","65","75","85+"))
        axis(side=2,line=-0.5,at=seq(0,0.1,by=0.02),las=1)
  par(mar=c(5,4,2,1)+0.1,ps=9)
    hist(OS_Fix$DBH.cm[which(OS_Fix$Silvi=="TH")], freq=F, axes=F,las=1,breaks=c(5,seq(15,85,by=10)),xlim=c(0,85),ylim=c(0,0.1),xlab=NULL, ylab=NULL, main=NULL, col="gray50")#thinning
      #text(100,120,labels=expression("mean BA = 19.3 m"^2*" ha"^-1), cex=1.3)
      text(x=5,y=0.095,adj=0,"Crown Thinning")
          axis(side=1,at=seq(5,85,by=10), labels=c("5","15","25","35","45","55","65","75","85+"))
          axis(side=2,line=-0.5,at=seq(0,0.1,by=0.02),las=1)    
    hist(OS_Fix$DBH.cm[which(OS_Fix$Silvi=="THMR")],freq=F, axes=F,las=1,breaks=c(5,seq(15,85,by=10)),xlim=c(0,85),ylim=c(0,0.1),xlab=NULL, ylab=NULL, main=NULL, col="gray50") #combo
      #text(100,120,labels=expression("mean BA = 17.9 m"^2*" ha"^-1), cex=1.3)  
      text(x=5,y=0.095,adj=0,"Shelterwood")
          axis(side=1,at=seq(5,85,by=10), labels=c("5","15","25","35","45","55","65","75","85+"))
          axis(side=2,line=-0.5,at=seq(0,0.1,by=0.02),las=1)   

mtext(side=1,outer=T,line=-2,"Diameter (cm)",cex=1)
mtext(side=2,outer=T,line=-0.5,"Density", cex=1)
#dev.off()

###################################
## In response to Reviewer #1:  ##
## How do we know that structure in 2018 is not mostly the result of storm damage? ##
###################################

# build size class distributions for 2010/11 for comparison
OS_11<-read.csv("Overstory DBH 2011.csv", header =T)
  OS_11<-OS_11[-which(is.na(OS_11$DBH.cm)),]
  OS_11<-OS_11[which(OS_11$DBH.cm>5),]
  
tiff(filename="Forests Fig. 2_Overstory Size Class_Rev1.tiff",width=6,height=8,units="in",res=400, pointsize=11, compression = "lzw")
OS_11$DBH.cm[which(OS_11$DBH.cm>85)] = 84.9 #hacky way to make a >85cm bin

par(mfrow=c(4,2),mar=c(3,4,2,1)+0.1, oma=c(4,4,0,0),ps=11) 

hist(OS_11$DBH.cm[which(OS_11$Trt_assignment=="Control")],freq=F,axes=F,las=1,breaks=c(5,seq(15,85,by=10)),xlim=c(0,85),ylim=c(0,0.10),xlab=NULL, ylab=NULL, main=NULL, col="gray50") #control
    text(x=5,y=0.095,adj=0,"Control")
    text(x=85,y=0.095,adj=1,"2010/11")
    axis(side=1,at=seq(5,85,by=10), labels=c("5","15","25","35","45","55","65","75","85+"))
    axis(side=2,line=-0.5,at=seq(0,0.10,by=0.02),las=1)
    
hist(OS_Fix$DBH.cm[which(OS_Fix$Silvi=="C")],freq=F,axes=F,las=1,breaks=c(5,seq(15,85,by=10)),xlim=c(0,85),ylim=c(0,0.10),xlab=NULL, ylab=NULL, main=NULL, col="gray50") #control
    text(x=5,y=0.095,adj=0,"Control")
    text(x=85,y=0.095,adj=1,"2018")
    axis(side=1,at=seq(5,85,by=10), labels=c("5","15","25","35","45","55","65","75","85+"))
    axis(side=2,line=-0.5,at=seq(0,0.10,by=0.02),las=1) 
    
hist(OS_11$DBH.cm[which(OS_11$Trt_assignment=="Midstory")],freq=F,axes=F,las=1,breaks=c(5,seq(15,85,by=10)),xlim=c(0,85),ylim=c(0,0.1),xlab=NULL, ylab=NULL, main=NULL, col="gray50") #midstory removal
    text(x=5,y=0.095,adj=0,"Midstory Removal")
    text(x=85,y=0.095,adj=1,"2010/11")
    axis(side=1,at=seq(5,85,by=10), labels=c("5","15","25","35","45","55","65","75","85+"))
    axis(side=2,line=-0.5,at=seq(0,0.1,by=0.02),las=1)
    
hist(OS_Fix$DBH.cm[which(OS_Fix$Silvi=="MR")],freq=F,axes=F,las=1,breaks=c(5,seq(15,85,by=10)),xlim=c(0,85),ylim=c(0,0.1),xlab=NULL, ylab=NULL, main=NULL, col="gray50") #midstory removal
    text(x=5,y=0.095,adj=0,"Midstory Removal")    
    text(x=85,y=0.095,adj=1,"2018")
    axis(side=1,at=seq(5,85,by=10), labels=c("5","15","25","35","45","55","65","75","85+"))
    axis(side=2,line=-0.5,at=seq(0,0.1,by=0.02),las=1)
    
#par(mar=c(5,4,2,1)+0.1,ps=9)
hist(OS_11$DBH.cm[which(OS_11$Trt_assignment=="Thinning")], freq=F, axes=F,las=1,breaks=c(5,seq(15,85,by=10)),xlim=c(0,85),ylim=c(0,0.1),xlab=NULL, ylab=NULL, main=NULL, col="gray50")#thinning
    text(x=5,y=0.095,adj=0,"Crown Thinning")
    text(x=85,y=0.095,adj=1,"2010/11")
    axis(side=1,at=seq(5,85,by=10), labels=c("5","15","25","35","45","55","65","75","85+"))
    axis(side=2,line=-0.5,at=seq(0,0.1,by=0.02),las=1)    
    
hist(OS_Fix$DBH.cm[which(OS_Fix$Silvi=="TH")], freq=F, axes=F,las=1,breaks=c(5,seq(15,85,by=10)),xlim=c(0,85),ylim=c(0,0.1),xlab=NULL, ylab=NULL, main=NULL, col="gray50")#thinning
    text(x=5,y=0.095,adj=0,"Crown Thinning")
    text(x=85,y=0.095,adj=1,"2018")
    axis(side=1,at=seq(5,85,by=10), labels=c("5","15","25","35","45","55","65","75","85+"))
    axis(side=2,line=-0.5,at=seq(0,0.1,by=0.02),las=1)        
    
hist(OS_11$DBH.cm[which(OS_11$Trt_assignment=="Shelterwood")],freq=F, axes=F,las=1,breaks=c(5,seq(15,85,by=10)),xlim=c(0,85),ylim=c(0,0.1),xlab=NULL, ylab=NULL, main=NULL, col="gray50") #combo
    text(x=5,y=0.095,adj=0,"Shelterwood")
    text(x=85,y=0.095,adj=1,"2010/11")
    axis(side=1,at=seq(5,85,by=10), labels=c("5","15","25","35","45","55","65","75","85+"))
    axis(side=2,line=-0.5,at=seq(0,0.1,by=0.02),las=1)   
    
hist(OS_Fix$DBH.cm[which(OS_Fix$Silvi=="THMR")],freq=F, axes=F,las=1,breaks=c(5,seq(15,85,by=10)),xlim=c(0,85),ylim=c(0,0.1),xlab=NULL, ylab=NULL, main=NULL, col="gray50") #combo
    text(x=5,y=0.095,adj=0,"Shelterwood")
    text(x=85,y=0.095,adj=1,"2018")
    axis(side=1,at=seq(5,85,by=10), labels=c("5","15","25","35","45","55","65","75","85+"))
    axis(side=2,line=-0.5,at=seq(0,0.1,by=0.02),las=1) 
    
mtext(side=1,outer=T,line=1,"Diameter at Breast Height (cm)",cex=0.8)
mtext(side=2,outer=T,line=1,"Density", cex=0.8)
dev.off()
